from typing import Any

from inui.base import BaseVoidElement
from inui.bootstrap.utils import bs_class_to_lower
from inui.conf import BOOTSTRAP_CSS_URL, BOOTSTRAP_JS_URL
from inui.elements import Link, Script


class BootStrapCSS(BaseVoidElement):

    def __init__(
        self, *data: Any, url: str = BOOTSTRAP_CSS_URL, **attributes: Any
    ) -> None:
        self.url = url
        super().__init__(*data, **attributes)

    def render(self, prettify: bool = False):
        return Link(href=self.url).render()


class BootStrapJS(BaseVoidElement):

    def __init__(
        self, *data: Any, url: str = BOOTSTRAP_JS_URL, **attributes: Any
    ) -> None:
        self.url = url
        super().__init__(*data, **attributes)

    def render(self, prettify: bool = False):
        return Script(src=self.url).render()


class BaseBS(BaseVoidElement):
    def __init__(self, *values) -> None:
        self.values = values

    def render(self, prettify: bool = False) -> str:
        values = ""
        if self.values:
            values += "-"
            values += "-".join(list(map(str, self.values)))
        return bs_class_to_lower(self.__class__.__name__) + values


class accordion_body(BaseBS): ...


class accordion_button(BaseBS): ...


class accordion_collapse(BaseBS): ...


class accordion_flush(BaseBS): ...


class accordion_header(BaseBS): ...


class accordion_item(BaseBS): ...


class active(BaseBS): ...


class alert(BaseBS): ...


class alert_danger(BaseBS): ...


class alert_dark(BaseBS): ...


class alert_dismissible(BaseBS): ...


class alert_heading(BaseBS): ...


class alert_info(BaseBS): ...


class alert_light(BaseBS): ...


class alert_link(BaseBS): ...


class alert_primary(BaseBS): ...


class alert_secondary(BaseBS): ...


class alert_success(BaseBS): ...


class alert_warning(BaseBS): ...


class align_baseline(BaseBS): ...


class align_bottom(BaseBS): ...


class align_content_around(BaseBS): ...


class align_content_between(BaseBS): ...


class align_content_center(BaseBS): ...


class align_content_end(BaseBS): ...


class align_content_lg_around(BaseBS): ...


class align_content_lg_between(BaseBS): ...


class align_content_lg_center(BaseBS): ...


class align_content_lg_end(BaseBS): ...


class align_content_lg_start(BaseBS): ...


class align_content_lg_stretch(BaseBS): ...


class align_content_md_around(BaseBS): ...


class align_content_md_between(BaseBS): ...


class align_content_md_center(BaseBS): ...


class align_content_md_end(BaseBS): ...


class align_content_md_start(BaseBS): ...


class align_content_md_stretch(BaseBS): ...


class align_content_sm_around(BaseBS): ...


class align_content_sm_between(BaseBS): ...


class align_content_sm_center(BaseBS): ...


class align_content_sm_end(BaseBS): ...


class align_content_sm_start(BaseBS): ...


class align_content_sm_stretch(BaseBS): ...


class align_content_start(BaseBS): ...


class align_content_stretch(BaseBS): ...


class align_content_xl_around(BaseBS): ...


class align_content_xl_between(BaseBS): ...


class align_content_xl_center(BaseBS): ...


class align_content_xl_end(BaseBS): ...


class align_content_xl_start(BaseBS): ...


class align_content_xl_stretch(BaseBS): ...


class align_content_xxl_around(BaseBS): ...


class align_content_xxl_between(BaseBS): ...


class align_content_xxl_center(BaseBS): ...


class align_content_xxl_end(BaseBS): ...


class align_content_xxl_start(BaseBS): ...


class align_content_xxl_stretch(BaseBS): ...


class align_items_baseline(BaseBS): ...


class align_items_center(BaseBS): ...


class align_items_end(BaseBS): ...


class align_items_lg_baseline(BaseBS): ...


class align_items_lg_center(BaseBS): ...


class align_items_lg_end(BaseBS): ...


class align_items_lg_start(BaseBS): ...


class align_items_lg_stretch(BaseBS): ...


class align_items_md_baseline(BaseBS): ...


class align_items_md_center(BaseBS): ...


class align_items_md_end(BaseBS): ...


class align_items_md_start(BaseBS): ...


class align_items_md_stretch(BaseBS): ...


class align_items_sm_baseline(BaseBS): ...


class align_items_sm_center(BaseBS): ...


class align_items_sm_end(BaseBS): ...


class align_items_sm_start(BaseBS): ...


class align_items_sm_stretch(BaseBS): ...


class align_items_start(BaseBS): ...


class align_items_stretch(BaseBS): ...


class align_items_xl_baseline(BaseBS): ...


class align_items_xl_center(BaseBS): ...


class align_items_xl_end(BaseBS): ...


class align_items_xl_start(BaseBS): ...


class align_items_xl_stretch(BaseBS): ...


class align_items_xxl_baseline(BaseBS): ...


class align_items_xxl_center(BaseBS): ...


class align_items_xxl_end(BaseBS): ...


class align_items_xxl_start(BaseBS): ...


class align_items_xxl_stretch(BaseBS): ...


class align_middle(BaseBS): ...


class align_self_auto(BaseBS): ...


class align_self_baseline(BaseBS): ...


class align_self_center(BaseBS): ...


class align_self_end(BaseBS): ...


class align_self_lg_auto(BaseBS): ...


class align_self_lg_baseline(BaseBS): ...


class align_self_lg_center(BaseBS): ...


class align_self_lg_end(BaseBS): ...


class align_self_lg_start(BaseBS): ...


class align_self_lg_stretch(BaseBS): ...


class align_self_md_auto(BaseBS): ...


class align_self_md_baseline(BaseBS): ...


class align_self_md_center(BaseBS): ...


class align_self_md_end(BaseBS): ...


class align_self_md_start(BaseBS): ...


class align_self_md_stretch(BaseBS): ...


class align_self_sm_auto(BaseBS): ...


class align_self_sm_baseline(BaseBS): ...


class align_self_sm_center(BaseBS): ...


class align_self_sm_end(BaseBS): ...


class align_self_sm_start(BaseBS): ...


class align_self_sm_stretch(BaseBS): ...


class align_self_start(BaseBS): ...


class align_self_stretch(BaseBS): ...


class align_self_xl_auto(BaseBS): ...


class align_self_xl_baseline(BaseBS): ...


class align_self_xl_center(BaseBS): ...


class align_self_xl_end(BaseBS): ...


class align_self_xl_start(BaseBS): ...


class align_self_xl_stretch(BaseBS): ...


class align_self_xxl_auto(BaseBS): ...


class align_self_xxl_baseline(BaseBS): ...


class align_self_xxl_center(BaseBS): ...


class align_self_xxl_end(BaseBS): ...


class align_self_xxl_start(BaseBS): ...


class align_self_xxl_stretch(BaseBS): ...


class align_text_bottom(BaseBS): ...


class align_text_top(BaseBS): ...


class align_top(BaseBS): ...


class badge(BaseBS): ...


class bg_black(BaseBS): ...


class bg_body(BaseBS): ...


class bg_danger(BaseBS): ...


class bg_dark(BaseBS): ...


class bg_gradient(BaseBS): ...


class bg_info(BaseBS): ...


class bg_light(BaseBS): ...


class bg_opacity_10(BaseBS): ...


class bg_opacity_100(BaseBS): ...


class bg_opacity_25(BaseBS): ...


class bg_opacity_50(BaseBS): ...


class bg_opacity_75(BaseBS): ...


class bg_primary(BaseBS): ...


class bg_secondary(BaseBS): ...


class bg_success(BaseBS): ...


class bg_transparent(BaseBS): ...


class bg_warning(BaseBS): ...


class bg_white(BaseBS): ...


class blockquote(BaseBS): ...


class blockquote_footer(BaseBS): ...


class border(BaseBS): ...


class border_0(BaseBS): ...


class border_1(BaseBS): ...


class border_2(BaseBS): ...


class border_3(BaseBS): ...


class border_4(BaseBS): ...


class border_5(BaseBS): ...


class border_bottom(BaseBS): ...


class border_bottom_0(BaseBS): ...


class border_danger(BaseBS): ...


class border_dark(BaseBS): ...


class border_end(BaseBS): ...


class border_end_0(BaseBS): ...


class border_info(BaseBS): ...


class border_light(BaseBS): ...


class border_primary(BaseBS): ...


class border_secondary(BaseBS): ...


class border_start(BaseBS): ...


class border_start_0(BaseBS): ...


class border_success(BaseBS): ...


class border_top(BaseBS): ...


class border_top_0(BaseBS): ...


class border_warning(BaseBS): ...


class border_white(BaseBS): ...


class bottom_0(BaseBS): ...


class bottom_100(BaseBS): ...


class bottom_50(BaseBS): ...


class breadcrumb(BaseBS): ...


class breadcrumb_item(BaseBS): ...


class bs_popover_auto(BaseBS): ...


class bs_popover_bottom(BaseBS): ...


class bs_popover_end(BaseBS): ...


class bs_popover_start(BaseBS): ...


class bs_popover_top(BaseBS): ...


class bs_tooltip_auto(BaseBS): ...


class bs_tooltip_bottom(BaseBS): ...


class bs_tooltip_end(BaseBS): ...


class bs_tooltip_start(BaseBS): ...


class bs_tooltip_top(BaseBS): ...


class btn(BaseBS): ...


class btn_check(BaseBS): ...


class btn_close(BaseBS): ...


class btn_close_white(BaseBS): ...


class btn_danger(BaseBS): ...


class btn_dark(BaseBS): ...


class btn_group(BaseBS): ...


class btn_group_lg(BaseBS): ...


class btn_group_sm(BaseBS): ...


class btn_group_vertical(BaseBS): ...


class btn_info(BaseBS): ...


class btn_lg(BaseBS): ...


class btn_light(BaseBS): ...


class btn_link(BaseBS): ...


class btn_outline_danger(BaseBS): ...


class btn_outline_dark(BaseBS): ...


class btn_outline_info(BaseBS): ...


class btn_outline_light(BaseBS): ...


class btn_outline_primary(BaseBS): ...


class btn_outline_secondary(BaseBS): ...


class btn_outline_success(BaseBS): ...


class btn_outline_warning(BaseBS): ...


class btn_primary(BaseBS): ...


class btn_secondary(BaseBS): ...


class btn_sm(BaseBS): ...


class btn_success(BaseBS): ...


class btn_toolbar(BaseBS): ...


class btn_warning(BaseBS): ...


class caption_top(BaseBS): ...


class card(BaseBS): ...


class card_body(BaseBS): ...


class card_footer(BaseBS): ...


class card_group(BaseBS): ...


class card_header(BaseBS): ...


class card_header_pills(BaseBS): ...


class card_header_tabs(BaseBS): ...


class card_img(BaseBS): ...


class card_img_bottom(BaseBS): ...


class card_img_overlay(BaseBS): ...


class card_img_top(BaseBS): ...


class card_link(BaseBS): ...


class card_subtitle(BaseBS): ...


class card_text(BaseBS): ...


class card_title(BaseBS): ...


class carousel(BaseBS): ...


class carousel_caption(BaseBS): ...


class carousel_control_next(BaseBS): ...


class carousel_control_next_icon(BaseBS): ...


class carousel_control_prev(BaseBS): ...


class carousel_control_prev_icon(BaseBS): ...


class carousel_dark(BaseBS): ...


class carousel_fade(BaseBS): ...


class carousel_indicators(BaseBS): ...


class carousel_inner(BaseBS): ...


class carousel_item(BaseBS): ...


class carousel_item_end(BaseBS): ...


class carousel_item_next(BaseBS): ...


class carousel_item_prev(BaseBS): ...


class carousel_item_start(BaseBS): ...


class clearfix(BaseBS): ...


class col(BaseBS): ...


class col_1(BaseBS): ...


class col_10(BaseBS): ...


class col_11(BaseBS): ...


class col_12(BaseBS): ...


class col_2(BaseBS): ...


class col_3(BaseBS): ...


class col_4(BaseBS): ...


class col_5(BaseBS): ...


class col_6(BaseBS): ...


class col_7(BaseBS): ...


class col_8(BaseBS): ...


class col_9(BaseBS): ...


class col_auto(BaseBS): ...


class col_form_label(BaseBS): ...


class col_form_label_lg(BaseBS): ...


class col_form_label_sm(BaseBS): ...


class col_lg(BaseBS): ...


class col_lg_1(BaseBS): ...


class col_lg_10(BaseBS): ...


class col_lg_11(BaseBS): ...


class col_lg_12(BaseBS): ...


class col_lg_2(BaseBS): ...


class col_lg_3(BaseBS): ...


class col_lg_4(BaseBS): ...


class col_lg_5(BaseBS): ...


class col_lg_6(BaseBS): ...


class col_lg_7(BaseBS): ...


class col_lg_8(BaseBS): ...


class col_lg_9(BaseBS): ...


class col_lg_auto(BaseBS): ...


class col_md(BaseBS): ...


class col_md_1(BaseBS): ...


class col_md_10(BaseBS): ...


class col_md_11(BaseBS): ...


class col_md_12(BaseBS): ...


class col_md_2(BaseBS): ...


class col_md_3(BaseBS): ...


class col_md_4(BaseBS): ...


class col_md_5(BaseBS): ...


class col_md_6(BaseBS): ...


class col_md_7(BaseBS): ...


class col_md_8(BaseBS): ...


class col_md_9(BaseBS): ...


class col_md_auto(BaseBS): ...


class col_sm(BaseBS): ...


class col_sm_1(BaseBS): ...


class col_sm_10(BaseBS): ...


class col_sm_11(BaseBS): ...


class col_sm_12(BaseBS): ...


class col_sm_2(BaseBS): ...


class col_sm_3(BaseBS): ...


class col_sm_4(BaseBS): ...


class col_sm_5(BaseBS): ...


class col_sm_6(BaseBS): ...


class col_sm_7(BaseBS): ...


class col_sm_8(BaseBS): ...


class col_sm_9(BaseBS): ...


class col_sm_auto(BaseBS): ...


class col_xl(BaseBS): ...


class col_xl_1(BaseBS): ...


class col_xl_10(BaseBS): ...


class col_xl_11(BaseBS): ...


class col_xl_12(BaseBS): ...


class col_xl_2(BaseBS): ...


class col_xl_3(BaseBS): ...


class col_xl_4(BaseBS): ...


class col_xl_5(BaseBS): ...


class col_xl_6(BaseBS): ...


class col_xl_7(BaseBS): ...


class col_xl_8(BaseBS): ...


class col_xl_9(BaseBS): ...


class col_xl_auto(BaseBS): ...


class col_xxl(BaseBS): ...


class col_xxl_1(BaseBS): ...


class col_xxl_10(BaseBS): ...


class col_xxl_11(BaseBS): ...


class col_xxl_12(BaseBS): ...


class col_xxl_2(BaseBS): ...


class col_xxl_3(BaseBS): ...


class col_xxl_4(BaseBS): ...


class col_xxl_5(BaseBS): ...


class col_xxl_6(BaseBS): ...


class col_xxl_7(BaseBS): ...


class col_xxl_8(BaseBS): ...


class col_xxl_9(BaseBS): ...


class col_xxl_auto(BaseBS): ...


class collapse(BaseBS): ...


class collapse_horizontal(BaseBS): ...


class collapsed(BaseBS): ...


class collapsing(BaseBS): ...


class container(BaseBS): ...


class container_fluid(BaseBS): ...


class container_lg(BaseBS): ...


class container_md(BaseBS): ...


class container_sm(BaseBS): ...


class container_xl(BaseBS): ...


class container_xxl(BaseBS): ...


class d_block(BaseBS): ...


class d_flex(BaseBS): ...


class d_grid(BaseBS): ...


class d_inline(BaseBS): ...


class d_inline_block(BaseBS): ...


class d_inline_flex(BaseBS): ...


class d_lg_block(BaseBS): ...


class d_lg_flex(BaseBS): ...


class d_lg_grid(BaseBS): ...


class d_lg_inline(BaseBS): ...


class d_lg_inline_block(BaseBS): ...


class d_lg_inline_flex(BaseBS): ...


class d_lg_none(BaseBS): ...


class d_lg_table(BaseBS): ...


class d_lg_table_cell(BaseBS): ...


class d_lg_table_row(BaseBS): ...


class d_md_block(BaseBS): ...


class d_md_flex(BaseBS): ...


class d_md_grid(BaseBS): ...


class d_md_inline(BaseBS): ...


class d_md_inline_block(BaseBS): ...


class d_md_inline_flex(BaseBS): ...


class d_md_none(BaseBS): ...


class d_md_table(BaseBS): ...


class d_md_table_cell(BaseBS): ...


class d_md_table_row(BaseBS): ...


class d_none(BaseBS): ...


class d_print_block(BaseBS): ...


class d_print_flex(BaseBS): ...


class d_print_grid(BaseBS): ...


class d_print_inline(BaseBS): ...


class d_print_inline_block(BaseBS): ...


class d_print_inline_flex(BaseBS): ...


class d_print_none(BaseBS): ...


class d_print_table(BaseBS): ...


class d_print_table_cell(BaseBS): ...


class d_print_table_row(BaseBS): ...


class d_sm_block(BaseBS): ...


class d_sm_flex(BaseBS): ...


class d_sm_grid(BaseBS): ...


class d_sm_inline(BaseBS): ...


class d_sm_inline_block(BaseBS): ...


class d_sm_inline_flex(BaseBS): ...


class d_sm_none(BaseBS): ...


class d_sm_table(BaseBS): ...


class d_sm_table_cell(BaseBS): ...


class d_sm_table_row(BaseBS): ...


class d_table(BaseBS): ...


class d_table_cell(BaseBS): ...


class d_table_row(BaseBS): ...


class d_xl_block(BaseBS): ...


class d_xl_flex(BaseBS): ...


class d_xl_grid(BaseBS): ...


class d_xl_inline(BaseBS): ...


class d_xl_inline_block(BaseBS): ...


class d_xl_inline_flex(BaseBS): ...


class d_xl_none(BaseBS): ...


class d_xl_table(BaseBS): ...


class d_xl_table_cell(BaseBS): ...


class d_xl_table_row(BaseBS): ...


class d_xxl_block(BaseBS): ...


class d_xxl_flex(BaseBS): ...


class d_xxl_grid(BaseBS): ...


class d_xxl_inline(BaseBS): ...


class d_xxl_inline_block(BaseBS): ...


class d_xxl_inline_flex(BaseBS): ...


class d_xxl_none(BaseBS): ...


class d_xxl_table(BaseBS): ...


class d_xxl_table_cell(BaseBS): ...


class d_xxl_table_row(BaseBS): ...


class disabled(BaseBS): ...


class display_1(BaseBS): ...


class display_2(BaseBS): ...


class display_3(BaseBS): ...


class display_4(BaseBS): ...


class display_5(BaseBS): ...


class display_6(BaseBS): ...


class dropdown(BaseBS): ...


class dropdown_divider(BaseBS): ...


class dropdown_header(BaseBS): ...


class dropdown_item(BaseBS): ...


class dropdown_item_text(BaseBS): ...


class dropdown_menu(BaseBS): ...


class dropdown_menu_dark(BaseBS): ...


class dropdown_menu_end(BaseBS): ...


class dropdown_menu_lg_end(BaseBS): ...


class dropdown_menu_lg_start(BaseBS): ...


class dropdown_menu_md_end(BaseBS): ...


class dropdown_menu_md_start(BaseBS): ...


class dropdown_menu_sm_end(BaseBS): ...


class dropdown_menu_sm_start(BaseBS): ...


class dropdown_menu_start(BaseBS): ...


class dropdown_menu_xl_end(BaseBS): ...


class dropdown_menu_xl_start(BaseBS): ...


class dropdown_menu_xxl_end(BaseBS): ...


class dropdown_menu_xxl_start(BaseBS): ...


class dropdown_toggle(BaseBS): ...


class dropdown_toggle_split(BaseBS): ...


class dropend(BaseBS): ...


class dropstart(BaseBS): ...


class dropup(BaseBS): ...


class end_0(BaseBS): ...


class end_100(BaseBS): ...


class end_50(BaseBS): ...


class fade(BaseBS): ...


class figure(BaseBS): ...


class figure_caption(BaseBS): ...


class figure_img(BaseBS): ...


class fixed_bottom(BaseBS): ...


class fixed_top(BaseBS): ...


class flex_column(BaseBS): ...


class flex_column_reverse(BaseBS): ...


class flex_fill(BaseBS): ...


class flex_grow_0(BaseBS): ...


class flex_grow_1(BaseBS): ...


class flex_lg_column(BaseBS): ...


class flex_lg_column_reverse(BaseBS): ...


class flex_lg_fill(BaseBS): ...


class flex_lg_grow_0(BaseBS): ...


class flex_lg_grow_1(BaseBS): ...


class flex_lg_nowrap(BaseBS): ...


class flex_lg_row(BaseBS): ...


class flex_lg_row_reverse(BaseBS): ...


class flex_lg_shrink_0(BaseBS): ...


class flex_lg_shrink_1(BaseBS): ...


class flex_lg_wrap(BaseBS): ...


class flex_lg_wrap_reverse(BaseBS): ...


class flex_md_column(BaseBS): ...


class flex_md_column_reverse(BaseBS): ...


class flex_md_fill(BaseBS): ...


class flex_md_grow_0(BaseBS): ...


class flex_md_grow_1(BaseBS): ...


class flex_md_nowrap(BaseBS): ...


class flex_md_row(BaseBS): ...


class flex_md_row_reverse(BaseBS): ...


class flex_md_shrink_0(BaseBS): ...


class flex_md_shrink_1(BaseBS): ...


class flex_md_wrap(BaseBS): ...


class flex_md_wrap_reverse(BaseBS): ...


class flex_nowrap(BaseBS): ...


class flex_row(BaseBS): ...


class flex_row_reverse(BaseBS): ...


class flex_shrink_0(BaseBS): ...


class flex_shrink_1(BaseBS): ...


class flex_sm_column(BaseBS): ...


class flex_sm_column_reverse(BaseBS): ...


class flex_sm_fill(BaseBS): ...


class flex_sm_grow_0(BaseBS): ...


class flex_sm_grow_1(BaseBS): ...


class flex_sm_nowrap(BaseBS): ...


class flex_sm_row(BaseBS): ...


class flex_sm_row_reverse(BaseBS): ...


class flex_sm_shrink_0(BaseBS): ...


class flex_sm_shrink_1(BaseBS): ...


class flex_sm_wrap(BaseBS): ...


class flex_sm_wrap_reverse(BaseBS): ...


class flex_wrap(BaseBS): ...


class flex_wrap_reverse(BaseBS): ...


class flex_xl_column(BaseBS): ...


class flex_xl_column_reverse(BaseBS): ...


class flex_xl_fill(BaseBS): ...


class flex_xl_grow_0(BaseBS): ...


class flex_xl_grow_1(BaseBS): ...


class flex_xl_nowrap(BaseBS): ...


class flex_xl_row(BaseBS): ...


class flex_xl_row_reverse(BaseBS): ...


class flex_xl_shrink_0(BaseBS): ...


class flex_xl_shrink_1(BaseBS): ...


class flex_xl_wrap(BaseBS): ...


class flex_xl_wrap_reverse(BaseBS): ...


class flex_xxl_column(BaseBS): ...


class flex_xxl_column_reverse(BaseBS): ...


class flex_xxl_fill(BaseBS): ...


class flex_xxl_grow_0(BaseBS): ...


class flex_xxl_grow_1(BaseBS): ...


class flex_xxl_nowrap(BaseBS): ...


class flex_xxl_row(BaseBS): ...


class flex_xxl_row_reverse(BaseBS): ...


class flex_xxl_shrink_0(BaseBS): ...


class flex_xxl_shrink_1(BaseBS): ...


class flex_xxl_wrap(BaseBS): ...


class flex_xxl_wrap_reverse(BaseBS): ...


class float_end(BaseBS): ...


class float_lg_end(BaseBS): ...


class float_lg_none(BaseBS): ...


class float_lg_start(BaseBS): ...


class float_md_end(BaseBS): ...


class float_md_none(BaseBS): ...


class float_md_start(BaseBS): ...


class float_none(BaseBS): ...


class float_sm_end(BaseBS): ...


class float_sm_none(BaseBS): ...


class float_sm_start(BaseBS): ...


class float_start(BaseBS): ...


class float_xl_end(BaseBS): ...


class float_xl_none(BaseBS): ...


class float_xl_start(BaseBS): ...


class float_xxl_end(BaseBS): ...


class float_xxl_none(BaseBS): ...


class float_xxl_start(BaseBS): ...


class font_monospace(BaseBS): ...


class form_check(BaseBS): ...


class form_check_inline(BaseBS): ...


class form_check_input(BaseBS): ...


class form_check_label(BaseBS): ...


class form_control(BaseBS): ...


class form_control_color(BaseBS): ...


class form_control_lg(BaseBS): ...


class form_control_plaintext(BaseBS): ...


class form_control_sm(BaseBS): ...


class form_floating(BaseBS): ...


class form_label(BaseBS): ...


class form_range(BaseBS): ...


class form_select(BaseBS): ...


class form_select_lg(BaseBS): ...


class form_select_sm(BaseBS): ...


class form_switch(BaseBS): ...


class form_text(BaseBS): ...


class fs_1(BaseBS): ...


class fs_2(BaseBS): ...


class fs_3(BaseBS): ...


class fs_4(BaseBS): ...


class fs_5(BaseBS): ...


class fs_6(BaseBS): ...


class fst_italic(BaseBS): ...


class fst_normal(BaseBS): ...


class fw_bold(BaseBS): ...


class fw_bolder(BaseBS): ...


class fw_light(BaseBS): ...


class fw_lighter(BaseBS): ...


class fw_normal(BaseBS): ...


class g_0(BaseBS): ...


class g_1(BaseBS): ...


class g_2(BaseBS): ...


class g_3(BaseBS): ...


class g_4(BaseBS): ...


class g_5(BaseBS): ...


class g_lg_0(BaseBS): ...


class g_lg_1(BaseBS): ...


class g_lg_2(BaseBS): ...


class g_lg_3(BaseBS): ...


class g_lg_4(BaseBS): ...


class g_lg_5(BaseBS): ...


class g_md_0(BaseBS): ...


class g_md_1(BaseBS): ...


class g_md_2(BaseBS): ...


class g_md_3(BaseBS): ...


class g_md_4(BaseBS): ...


class g_md_5(BaseBS): ...


class g_sm_0(BaseBS): ...


class g_sm_1(BaseBS): ...


class g_sm_2(BaseBS): ...


class g_sm_3(BaseBS): ...


class g_sm_4(BaseBS): ...


class g_sm_5(BaseBS): ...


class g_xl_0(BaseBS): ...


class g_xl_1(BaseBS): ...


class g_xl_2(BaseBS): ...


class g_xl_3(BaseBS): ...


class g_xl_4(BaseBS): ...


class g_xl_5(BaseBS): ...


class g_xxl_0(BaseBS): ...


class g_xxl_1(BaseBS): ...


class g_xxl_2(BaseBS): ...


class g_xxl_3(BaseBS): ...


class g_xxl_4(BaseBS): ...


class g_xxl_5(BaseBS): ...


class gap_0(BaseBS): ...


class gap_1(BaseBS): ...


class gap_2(BaseBS): ...


class gap_3(BaseBS): ...


class gap_4(BaseBS): ...


class gap_5(BaseBS): ...


class gap_lg_0(BaseBS): ...


class gap_lg_1(BaseBS): ...


class gap_lg_2(BaseBS): ...


class gap_lg_3(BaseBS): ...


class gap_lg_4(BaseBS): ...


class gap_lg_5(BaseBS): ...


class gap_md_0(BaseBS): ...


class gap_md_1(BaseBS): ...


class gap_md_2(BaseBS): ...


class gap_md_3(BaseBS): ...


class gap_md_4(BaseBS): ...


class gap_md_5(BaseBS): ...


class gap_sm_0(BaseBS): ...


class gap_sm_1(BaseBS): ...


class gap_sm_2(BaseBS): ...


class gap_sm_3(BaseBS): ...


class gap_sm_4(BaseBS): ...


class gap_sm_5(BaseBS): ...


class gap_xl_0(BaseBS): ...


class gap_xl_1(BaseBS): ...


class gap_xl_2(BaseBS): ...


class gap_xl_3(BaseBS): ...


class gap_xl_4(BaseBS): ...


class gap_xl_5(BaseBS): ...


class gap_xxl_0(BaseBS): ...


class gap_xxl_1(BaseBS): ...


class gap_xxl_2(BaseBS): ...


class gap_xxl_3(BaseBS): ...


class gap_xxl_4(BaseBS): ...


class gap_xxl_5(BaseBS): ...


class gx_0(BaseBS): ...


class gx_1(BaseBS): ...


class gx_2(BaseBS): ...


class gx_3(BaseBS): ...


class gx_4(BaseBS): ...


class gx_5(BaseBS): ...


class gx_lg_0(BaseBS): ...


class gx_lg_1(BaseBS): ...


class gx_lg_2(BaseBS): ...


class gx_lg_3(BaseBS): ...


class gx_lg_4(BaseBS): ...


class gx_lg_5(BaseBS): ...


class gx_md_0(BaseBS): ...


class gx_md_1(BaseBS): ...


class gx_md_2(BaseBS): ...


class gx_md_3(BaseBS): ...


class gx_md_4(BaseBS): ...


class gx_md_5(BaseBS): ...


class gx_sm_0(BaseBS): ...


class gx_sm_1(BaseBS): ...


class gx_sm_2(BaseBS): ...


class gx_sm_3(BaseBS): ...


class gx_sm_4(BaseBS): ...


class gx_sm_5(BaseBS): ...


class gx_xl_0(BaseBS): ...


class gx_xl_1(BaseBS): ...


class gx_xl_2(BaseBS): ...


class gx_xl_3(BaseBS): ...


class gx_xl_4(BaseBS): ...


class gx_xl_5(BaseBS): ...


class gx_xxl_0(BaseBS): ...


class gx_xxl_1(BaseBS): ...


class gx_xxl_2(BaseBS): ...


class gx_xxl_3(BaseBS): ...


class gx_xxl_4(BaseBS): ...


class gx_xxl_5(BaseBS): ...


class gy_0(BaseBS): ...


class gy_1(BaseBS): ...


class gy_2(BaseBS): ...


class gy_3(BaseBS): ...


class gy_4(BaseBS): ...


class gy_5(BaseBS): ...


class gy_lg_0(BaseBS): ...


class gy_lg_1(BaseBS): ...


class gy_lg_2(BaseBS): ...


class gy_lg_3(BaseBS): ...


class gy_lg_4(BaseBS): ...


class gy_lg_5(BaseBS): ...


class gy_md_0(BaseBS): ...


class gy_md_1(BaseBS): ...


class gy_md_2(BaseBS): ...


class gy_md_3(BaseBS): ...


class gy_md_4(BaseBS): ...


class gy_md_5(BaseBS): ...


class gy_sm_0(BaseBS): ...


class gy_sm_1(BaseBS): ...


class gy_sm_2(BaseBS): ...


class gy_sm_3(BaseBS): ...


class gy_sm_4(BaseBS): ...


class gy_sm_5(BaseBS): ...


class gy_xl_0(BaseBS): ...


class gy_xl_1(BaseBS): ...


class gy_xl_2(BaseBS): ...


class gy_xl_3(BaseBS): ...


class gy_xl_4(BaseBS): ...


class gy_xl_5(BaseBS): ...


class gy_xxl_0(BaseBS): ...


class gy_xxl_1(BaseBS): ...


class gy_xxl_2(BaseBS): ...


class gy_xxl_3(BaseBS): ...


class gy_xxl_4(BaseBS): ...


class gy_xxl_5(BaseBS): ...


class h_100(BaseBS): ...


class h_25(BaseBS): ...


class h_50(BaseBS): ...


class h_75(BaseBS): ...


class h_auto(BaseBS): ...


class h1(BaseBS): ...


class h2(BaseBS): ...


class h3(BaseBS): ...


class h4(BaseBS): ...


class h5(BaseBS): ...


class h6(BaseBS): ...


class has_validation(BaseBS): ...


class hstack(BaseBS): ...


class img_fluid(BaseBS): ...


class img_thumbnail(BaseBS): ...


class initialism(BaseBS): ...


class input_group(BaseBS): ...


class input_group_lg(BaseBS): ...


class input_group_sm(BaseBS): ...


class input_group_text(BaseBS): ...


class invalid_feedback(BaseBS): ...


class invalid_tooltip(BaseBS): ...


class invisible(BaseBS): ...


class is_invalid(BaseBS): ...


class is_valid(BaseBS): ...


class justify_content_around(BaseBS): ...


class justify_content_between(BaseBS): ...


class justify_content_center(BaseBS): ...


class justify_content_end(BaseBS): ...


class justify_content_evenly(BaseBS): ...


class justify_content_lg_around(BaseBS): ...


class justify_content_lg_between(BaseBS): ...


class justify_content_lg_center(BaseBS): ...


class justify_content_lg_end(BaseBS): ...


class justify_content_lg_evenly(BaseBS): ...


class justify_content_lg_start(BaseBS): ...


class justify_content_md_around(BaseBS): ...


class justify_content_md_between(BaseBS): ...


class justify_content_md_center(BaseBS): ...


class justify_content_md_end(BaseBS): ...


class justify_content_md_evenly(BaseBS): ...


class justify_content_md_start(BaseBS): ...


class justify_content_sm_around(BaseBS): ...


class justify_content_sm_between(BaseBS): ...


class justify_content_sm_center(BaseBS): ...


class justify_content_sm_end(BaseBS): ...


class justify_content_sm_evenly(BaseBS): ...


class justify_content_sm_start(BaseBS): ...


class justify_content_start(BaseBS): ...


class justify_content_xl_around(BaseBS): ...


class justify_content_xl_between(BaseBS): ...


class justify_content_xl_center(BaseBS): ...


class justify_content_xl_end(BaseBS): ...


class justify_content_xl_evenly(BaseBS): ...


class justify_content_xl_start(BaseBS): ...


class justify_content_xxl_around(BaseBS): ...


class justify_content_xxl_between(BaseBS): ...


class justify_content_xxl_center(BaseBS): ...


class justify_content_xxl_end(BaseBS): ...


class justify_content_xxl_evenly(BaseBS): ...


class justify_content_xxl_start(BaseBS): ...


class lead(BaseBS): ...


class lh_1(BaseBS): ...


class lh_base(BaseBS): ...


class lh_lg(BaseBS): ...


class lh_sm(BaseBS): ...


class link_danger(BaseBS): ...


class link_dark(BaseBS): ...


class link_info(BaseBS): ...


class link_light(BaseBS): ...


class link_primary(BaseBS): ...


class link_secondary(BaseBS): ...


class link_success(BaseBS): ...


class link_warning(BaseBS): ...


class list_group(BaseBS): ...


class list_group_flush(BaseBS): ...


class list_group_horizontal(BaseBS): ...


class list_group_horizontal_lg(BaseBS): ...


class list_group_horizontal_md(BaseBS): ...


class list_group_horizontal_sm(BaseBS): ...


class list_group_horizontal_xl(BaseBS): ...


class list_group_horizontal_xxl(BaseBS): ...


class list_group_item(BaseBS): ...


class list_group_item_action(BaseBS): ...


class list_group_item_danger(BaseBS): ...


class list_group_item_dark(BaseBS): ...


class list_group_item_info(BaseBS): ...


class list_group_item_light(BaseBS): ...


class list_group_item_primary(BaseBS): ...


class list_group_item_secondary(BaseBS): ...


class list_group_item_success(BaseBS): ...


class list_group_item_warning(BaseBS): ...


class list_group_numbered(BaseBS): ...


class list_inline(BaseBS): ...


class list_inline_item(BaseBS): ...


class list_unstyled(BaseBS): ...


class m_0(BaseBS): ...


class m_1(BaseBS): ...


class m_2(BaseBS): ...


class m_3(BaseBS): ...


class m_4(BaseBS): ...


class m_5(BaseBS): ...


class m_auto(BaseBS): ...


class m_lg_0(BaseBS): ...


class m_lg_1(BaseBS): ...


class m_lg_2(BaseBS): ...


class m_lg_3(BaseBS): ...


class m_lg_4(BaseBS): ...


class m_lg_5(BaseBS): ...


class m_lg_auto(BaseBS): ...


class m_md_0(BaseBS): ...


class m_md_1(BaseBS): ...


class m_md_2(BaseBS): ...


class m_md_3(BaseBS): ...


class m_md_4(BaseBS): ...


class m_md_5(BaseBS): ...


class m_md_auto(BaseBS): ...


class m_sm_0(BaseBS): ...


class m_sm_1(BaseBS): ...


class m_sm_2(BaseBS): ...


class m_sm_3(BaseBS): ...


class m_sm_4(BaseBS): ...


class m_sm_5(BaseBS): ...


class m_sm_auto(BaseBS): ...


class m_xl_0(BaseBS): ...


class m_xl_1(BaseBS): ...


class m_xl_2(BaseBS): ...


class m_xl_3(BaseBS): ...


class m_xl_4(BaseBS): ...


class m_xl_5(BaseBS): ...


class m_xl_auto(BaseBS): ...


class m_xxl_0(BaseBS): ...


class m_xxl_1(BaseBS): ...


class m_xxl_2(BaseBS): ...


class m_xxl_3(BaseBS): ...


class m_xxl_4(BaseBS): ...


class m_xxl_5(BaseBS): ...


class m_xxl_auto(BaseBS): ...


class mark(BaseBS): ...


class mb_0(BaseBS): ...


class mb_1(BaseBS): ...


class mb_2(BaseBS): ...


class mb_3(BaseBS): ...


class mb_4(BaseBS): ...


class mb_5(BaseBS): ...


class mb_auto(BaseBS): ...


class mb_lg_0(BaseBS): ...


class mb_lg_1(BaseBS): ...


class mb_lg_2(BaseBS): ...


class mb_lg_3(BaseBS): ...


class mb_lg_4(BaseBS): ...


class mb_lg_5(BaseBS): ...


class mb_lg_auto(BaseBS): ...


class mb_md_0(BaseBS): ...


class mb_md_1(BaseBS): ...


class mb_md_2(BaseBS): ...


class mb_md_3(BaseBS): ...


class mb_md_4(BaseBS): ...


class mb_md_5(BaseBS): ...


class mb_md_auto(BaseBS): ...


class mb_sm_0(BaseBS): ...


class mb_sm_1(BaseBS): ...


class mb_sm_2(BaseBS): ...


class mb_sm_3(BaseBS): ...


class mb_sm_4(BaseBS): ...


class mb_sm_5(BaseBS): ...


class mb_sm_auto(BaseBS): ...


class mb_xl_0(BaseBS): ...


class mb_xl_1(BaseBS): ...


class mb_xl_2(BaseBS): ...


class mb_xl_3(BaseBS): ...


class mb_xl_4(BaseBS): ...


class mb_xl_5(BaseBS): ...


class mb_xl_auto(BaseBS): ...


class mb_xxl_0(BaseBS): ...


class mb_xxl_1(BaseBS): ...


class mb_xxl_2(BaseBS): ...


class mb_xxl_3(BaseBS): ...


class mb_xxl_4(BaseBS): ...


class mb_xxl_5(BaseBS): ...


class mb_xxl_auto(BaseBS): ...


class me_0(BaseBS): ...


class me_1(BaseBS): ...


class me_2(BaseBS): ...


class me_3(BaseBS): ...


class me_4(BaseBS): ...


class me_5(BaseBS): ...


class me_auto(BaseBS): ...


class me_lg_0(BaseBS): ...


class me_lg_1(BaseBS): ...


class me_lg_2(BaseBS): ...


class me_lg_3(BaseBS): ...


class me_lg_4(BaseBS): ...


class me_lg_5(BaseBS): ...


class me_lg_auto(BaseBS): ...


class me_md_0(BaseBS): ...


class me_md_1(BaseBS): ...


class me_md_2(BaseBS): ...


class me_md_3(BaseBS): ...


class me_md_4(BaseBS): ...


class me_md_5(BaseBS): ...


class me_md_auto(BaseBS): ...


class me_sm_0(BaseBS): ...


class me_sm_1(BaseBS): ...


class me_sm_2(BaseBS): ...


class me_sm_3(BaseBS): ...


class me_sm_4(BaseBS): ...


class me_sm_5(BaseBS): ...


class me_sm_auto(BaseBS): ...


class me_xl_0(BaseBS): ...


class me_xl_1(BaseBS): ...


class me_xl_2(BaseBS): ...


class me_xl_3(BaseBS): ...


class me_xl_4(BaseBS): ...


class me_xl_5(BaseBS): ...


class me_xl_auto(BaseBS): ...


class me_xxl_0(BaseBS): ...


class me_xxl_1(BaseBS): ...


class me_xxl_2(BaseBS): ...


class me_xxl_3(BaseBS): ...


class me_xxl_4(BaseBS): ...


class me_xxl_5(BaseBS): ...


class me_xxl_auto(BaseBS): ...


class mh_100(BaseBS): ...


class min_vh_100(BaseBS): ...


class min_vw_100(BaseBS): ...


class modal(BaseBS): ...


class modal_backdrop(BaseBS): ...


class modal_body(BaseBS): ...


class modal_content(BaseBS): ...


class modal_dialog(BaseBS): ...


class modal_dialog_centered(BaseBS): ...


class modal_dialog_scrollable(BaseBS): ...


class modal_footer(BaseBS): ...


class modal_fullscreen(BaseBS): ...


class modal_fullscreen_lg_down(BaseBS): ...


class modal_fullscreen_md_down(BaseBS): ...


class modal_fullscreen_sm_down(BaseBS): ...


class modal_fullscreen_xl_down(BaseBS): ...


class modal_fullscreen_xxl_down(BaseBS): ...


class modal_header(BaseBS): ...


class modal_lg(BaseBS): ...


class modal_sm(BaseBS): ...


class modal_static(BaseBS): ...


class modal_title(BaseBS): ...


class modal_xl(BaseBS): ...


class ms_0(BaseBS): ...


class ms_1(BaseBS): ...


class ms_2(BaseBS): ...


class ms_3(BaseBS): ...


class ms_4(BaseBS): ...


class ms_5(BaseBS): ...


class ms_auto(BaseBS): ...


class ms_lg_0(BaseBS): ...


class ms_lg_1(BaseBS): ...


class ms_lg_2(BaseBS): ...


class ms_lg_3(BaseBS): ...


class ms_lg_4(BaseBS): ...


class ms_lg_5(BaseBS): ...


class ms_lg_auto(BaseBS): ...


class ms_md_0(BaseBS): ...


class ms_md_1(BaseBS): ...


class ms_md_2(BaseBS): ...


class ms_md_3(BaseBS): ...


class ms_md_4(BaseBS): ...


class ms_md_5(BaseBS): ...


class ms_md_auto(BaseBS): ...


class ms_sm_0(BaseBS): ...


class ms_sm_1(BaseBS): ...


class ms_sm_2(BaseBS): ...


class ms_sm_3(BaseBS): ...


class ms_sm_4(BaseBS): ...


class ms_sm_5(BaseBS): ...


class ms_sm_auto(BaseBS): ...


class ms_xl_0(BaseBS): ...


class ms_xl_1(BaseBS): ...


class ms_xl_2(BaseBS): ...


class ms_xl_3(BaseBS): ...


class ms_xl_4(BaseBS): ...


class ms_xl_5(BaseBS): ...


class ms_xl_auto(BaseBS): ...


class ms_xxl_0(BaseBS): ...


class ms_xxl_1(BaseBS): ...


class ms_xxl_2(BaseBS): ...


class ms_xxl_3(BaseBS): ...


class ms_xxl_4(BaseBS): ...


class ms_xxl_5(BaseBS): ...


class ms_xxl_auto(BaseBS): ...


class mt_0(BaseBS): ...


class mt_1(BaseBS): ...


class mt_2(BaseBS): ...


class mt_3(BaseBS): ...


class mt_4(BaseBS): ...


class mt_5(BaseBS): ...


class mt_auto(BaseBS): ...


class mt_lg_0(BaseBS): ...


class mt_lg_1(BaseBS): ...


class mt_lg_2(BaseBS): ...


class mt_lg_3(BaseBS): ...


class mt_lg_4(BaseBS): ...


class mt_lg_5(BaseBS): ...


class mt_lg_auto(BaseBS): ...


class mt_md_0(BaseBS): ...


class mt_md_1(BaseBS): ...


class mt_md_2(BaseBS): ...


class mt_md_3(BaseBS): ...


class mt_md_4(BaseBS): ...


class mt_md_5(BaseBS): ...


class mt_md_auto(BaseBS): ...


class mt_sm_0(BaseBS): ...


class mt_sm_1(BaseBS): ...


class mt_sm_2(BaseBS): ...


class mt_sm_3(BaseBS): ...


class mt_sm_4(BaseBS): ...


class mt_sm_5(BaseBS): ...


class mt_sm_auto(BaseBS): ...


class mt_xl_0(BaseBS): ...


class mt_xl_1(BaseBS): ...


class mt_xl_2(BaseBS): ...


class mt_xl_3(BaseBS): ...


class mt_xl_4(BaseBS): ...


class mt_xl_5(BaseBS): ...


class mt_xl_auto(BaseBS): ...


class mt_xxl_0(BaseBS): ...


class mt_xxl_1(BaseBS): ...


class mt_xxl_2(BaseBS): ...


class mt_xxl_3(BaseBS): ...


class mt_xxl_4(BaseBS): ...


class mt_xxl_5(BaseBS): ...


class mt_xxl_auto(BaseBS): ...


class mw_100(BaseBS): ...


class mx_0(BaseBS): ...


class mx_1(BaseBS): ...


class mx_2(BaseBS): ...


class mx_3(BaseBS): ...


class mx_4(BaseBS): ...


class mx_5(BaseBS): ...


class mx_auto(BaseBS): ...


class mx_lg_0(BaseBS): ...


class mx_lg_1(BaseBS): ...


class mx_lg_2(BaseBS): ...


class mx_lg_3(BaseBS): ...


class mx_lg_4(BaseBS): ...


class mx_lg_5(BaseBS): ...


class mx_lg_auto(BaseBS): ...


class mx_md_0(BaseBS): ...


class mx_md_1(BaseBS): ...


class mx_md_2(BaseBS): ...


class mx_md_3(BaseBS): ...


class mx_md_4(BaseBS): ...


class mx_md_5(BaseBS): ...


class mx_md_auto(BaseBS): ...


class mx_sm_0(BaseBS): ...


class mx_sm_1(BaseBS): ...


class mx_sm_2(BaseBS): ...


class mx_sm_3(BaseBS): ...


class mx_sm_4(BaseBS): ...


class mx_sm_5(BaseBS): ...


class mx_sm_auto(BaseBS): ...


class mx_xl_0(BaseBS): ...


class mx_xl_1(BaseBS): ...


class mx_xl_2(BaseBS): ...


class mx_xl_3(BaseBS): ...


class mx_xl_4(BaseBS): ...


class mx_xl_5(BaseBS): ...


class mx_xl_auto(BaseBS): ...


class mx_xxl_0(BaseBS): ...


class mx_xxl_1(BaseBS): ...


class mx_xxl_2(BaseBS): ...


class mx_xxl_3(BaseBS): ...


class mx_xxl_4(BaseBS): ...


class mx_xxl_5(BaseBS): ...


class mx_xxl_auto(BaseBS): ...


class my_0(BaseBS): ...


class my_1(BaseBS): ...


class my_2(BaseBS): ...


class my_3(BaseBS): ...


class my_4(BaseBS): ...


class my_5(BaseBS): ...


class my_auto(BaseBS): ...


class my_lg_0(BaseBS): ...


class my_lg_1(BaseBS): ...


class my_lg_2(BaseBS): ...


class my_lg_3(BaseBS): ...


class my_lg_4(BaseBS): ...


class my_lg_5(BaseBS): ...


class my_lg_auto(BaseBS): ...


class my_md_0(BaseBS): ...


class my_md_1(BaseBS): ...


class my_md_2(BaseBS): ...


class my_md_3(BaseBS): ...


class my_md_4(BaseBS): ...


class my_md_5(BaseBS): ...


class my_md_auto(BaseBS): ...


class my_sm_0(BaseBS): ...


class my_sm_1(BaseBS): ...


class my_sm_2(BaseBS): ...


class my_sm_3(BaseBS): ...


class my_sm_4(BaseBS): ...


class my_sm_5(BaseBS): ...


class my_sm_auto(BaseBS): ...


class my_xl_0(BaseBS): ...


class my_xl_1(BaseBS): ...


class my_xl_2(BaseBS): ...


class my_xl_3(BaseBS): ...


class my_xl_4(BaseBS): ...


class my_xl_5(BaseBS): ...


class my_xl_auto(BaseBS): ...


class my_xxl_0(BaseBS): ...


class my_xxl_1(BaseBS): ...


class my_xxl_2(BaseBS): ...


class my_xxl_3(BaseBS): ...


class my_xxl_4(BaseBS): ...


class my_xxl_5(BaseBS): ...


class my_xxl_auto(BaseBS): ...


class nav(BaseBS): ...


class nav_fill(BaseBS): ...


class nav_item(BaseBS): ...


class nav_justified(BaseBS): ...


class nav_link(BaseBS): ...


class nav_pills(BaseBS): ...


class nav_tabs(BaseBS): ...


class navbar(BaseBS): ...


class navbar_brand(BaseBS): ...


class navbar_collapse(BaseBS): ...


class navbar_dark(BaseBS): ...


class navbar_expand(BaseBS): ...


class navbar_expand_lg(BaseBS): ...


class navbar_expand_md(BaseBS): ...


class navbar_expand_sm(BaseBS): ...


class navbar_expand_xl(BaseBS): ...


class navbar_expand_xxl(BaseBS): ...


class navbar_light(BaseBS): ...


class navbar_nav(BaseBS): ...


class navbar_nav_scroll(BaseBS): ...


class navbar_text(BaseBS): ...


class navbar_toggler(BaseBS): ...


class navbar_toggler_icon(BaseBS): ...


class offcanvas(BaseBS): ...


class offcanvas_backdrop(BaseBS): ...


class offcanvas_body(BaseBS): ...


class offcanvas_bottom(BaseBS): ...


class offcanvas_end(BaseBS): ...


class offcanvas_header(BaseBS): ...


class offcanvas_start(BaseBS): ...


class offcanvas_title(BaseBS): ...


class offcanvas_top(BaseBS): ...


class offset_1(BaseBS): ...


class offset_10(BaseBS): ...


class offset_11(BaseBS): ...


class offset_2(BaseBS): ...


class offset_3(BaseBS): ...


class offset_4(BaseBS): ...


class offset_5(BaseBS): ...


class offset_6(BaseBS): ...


class offset_7(BaseBS): ...


class offset_8(BaseBS): ...


class offset_9(BaseBS): ...


class offset_lg_0(BaseBS): ...


class offset_lg_1(BaseBS): ...


class offset_lg_10(BaseBS): ...


class offset_lg_11(BaseBS): ...


class offset_lg_2(BaseBS): ...


class offset_lg_3(BaseBS): ...


class offset_lg_4(BaseBS): ...


class offset_lg_5(BaseBS): ...


class offset_lg_6(BaseBS): ...


class offset_lg_7(BaseBS): ...


class offset_lg_8(BaseBS): ...


class offset_lg_9(BaseBS): ...


class offset_md_0(BaseBS): ...


class offset_md_1(BaseBS): ...


class offset_md_10(BaseBS): ...


class offset_md_11(BaseBS): ...


class offset_md_2(BaseBS): ...


class offset_md_3(BaseBS): ...


class offset_md_4(BaseBS): ...


class offset_md_5(BaseBS): ...


class offset_md_6(BaseBS): ...


class offset_md_7(BaseBS): ...


class offset_md_8(BaseBS): ...


class offset_md_9(BaseBS): ...


class offset_sm_0(BaseBS): ...


class offset_sm_1(BaseBS): ...


class offset_sm_10(BaseBS): ...


class offset_sm_11(BaseBS): ...


class offset_sm_2(BaseBS): ...


class offset_sm_3(BaseBS): ...


class offset_sm_4(BaseBS): ...


class offset_sm_5(BaseBS): ...


class offset_sm_6(BaseBS): ...


class offset_sm_7(BaseBS): ...


class offset_sm_8(BaseBS): ...


class offset_sm_9(BaseBS): ...


class offset_xl_0(BaseBS): ...


class offset_xl_1(BaseBS): ...


class offset_xl_10(BaseBS): ...


class offset_xl_11(BaseBS): ...


class offset_xl_2(BaseBS): ...


class offset_xl_3(BaseBS): ...


class offset_xl_4(BaseBS): ...


class offset_xl_5(BaseBS): ...


class offset_xl_6(BaseBS): ...


class offset_xl_7(BaseBS): ...


class offset_xl_8(BaseBS): ...


class offset_xl_9(BaseBS): ...


class offset_xxl_0(BaseBS): ...


class offset_xxl_1(BaseBS): ...


class offset_xxl_10(BaseBS): ...


class offset_xxl_11(BaseBS): ...


class offset_xxl_2(BaseBS): ...


class offset_xxl_3(BaseBS): ...


class offset_xxl_4(BaseBS): ...


class offset_xxl_5(BaseBS): ...


class offset_xxl_6(BaseBS): ...


class offset_xxl_7(BaseBS): ...


class offset_xxl_8(BaseBS): ...


class offset_xxl_9(BaseBS): ...


class opacity_0(BaseBS): ...


class opacity_100(BaseBS): ...


class opacity_25(BaseBS): ...


class opacity_50(BaseBS): ...


class opacity_75(BaseBS): ...


class order_0(BaseBS): ...


class order_1(BaseBS): ...


class order_2(BaseBS): ...


class order_3(BaseBS): ...


class order_4(BaseBS): ...


class order_5(BaseBS): ...


class order_first(BaseBS): ...


class order_last(BaseBS): ...


class order_lg_0(BaseBS): ...


class order_lg_1(BaseBS): ...


class order_lg_2(BaseBS): ...


class order_lg_3(BaseBS): ...


class order_lg_4(BaseBS): ...


class order_lg_5(BaseBS): ...


class order_lg_first(BaseBS): ...


class order_lg_last(BaseBS): ...


class order_md_0(BaseBS): ...


class order_md_1(BaseBS): ...


class order_md_2(BaseBS): ...


class order_md_3(BaseBS): ...


class order_md_4(BaseBS): ...


class order_md_5(BaseBS): ...


class order_md_first(BaseBS): ...


class order_md_last(BaseBS): ...


class order_sm_0(BaseBS): ...


class order_sm_1(BaseBS): ...


class order_sm_2(BaseBS): ...


class order_sm_3(BaseBS): ...


class order_sm_4(BaseBS): ...


class order_sm_5(BaseBS): ...


class order_sm_first(BaseBS): ...


class order_sm_last(BaseBS): ...


class order_xl_0(BaseBS): ...


class order_xl_1(BaseBS): ...


class order_xl_2(BaseBS): ...


class order_xl_3(BaseBS): ...


class order_xl_4(BaseBS): ...


class order_xl_5(BaseBS): ...


class order_xl_first(BaseBS): ...


class order_xl_last(BaseBS): ...


class order_xxl_0(BaseBS): ...


class order_xxl_1(BaseBS): ...


class order_xxl_2(BaseBS): ...


class order_xxl_3(BaseBS): ...


class order_xxl_4(BaseBS): ...


class order_xxl_5(BaseBS): ...


class order_xxl_first(BaseBS): ...


class order_xxl_last(BaseBS): ...


class overflow_auto(BaseBS): ...


class overflow_hidden(BaseBS): ...


class overflow_scroll(BaseBS): ...


class overflow_visible(BaseBS): ...


class p_0(BaseBS): ...


class p_1(BaseBS): ...


class p_2(BaseBS): ...


class p_3(BaseBS): ...


class p_4(BaseBS): ...


class p_5(BaseBS): ...


class p_lg_0(BaseBS): ...


class p_lg_1(BaseBS): ...


class p_lg_2(BaseBS): ...


class p_lg_3(BaseBS): ...


class p_lg_4(BaseBS): ...


class p_lg_5(BaseBS): ...


class p_md_0(BaseBS): ...


class p_md_1(BaseBS): ...


class p_md_2(BaseBS): ...


class p_md_3(BaseBS): ...


class p_md_4(BaseBS): ...


class p_md_5(BaseBS): ...


class p_sm_0(BaseBS): ...


class p_sm_1(BaseBS): ...


class p_sm_2(BaseBS): ...


class p_sm_3(BaseBS): ...


class p_sm_4(BaseBS): ...


class p_sm_5(BaseBS): ...


class p_xl_0(BaseBS): ...


class p_xl_1(BaseBS): ...


class p_xl_2(BaseBS): ...


class p_xl_3(BaseBS): ...


class p_xl_4(BaseBS): ...


class p_xl_5(BaseBS): ...


class p_xxl_0(BaseBS): ...


class p_xxl_1(BaseBS): ...


class p_xxl_2(BaseBS): ...


class p_xxl_3(BaseBS): ...


class p_xxl_4(BaseBS): ...


class p_xxl_5(BaseBS): ...


class page_item(BaseBS): ...


class page_link(BaseBS): ...


class pagination(BaseBS): ...


class pagination_lg(BaseBS): ...


class pagination_sm(BaseBS): ...


class pb_0(BaseBS): ...


class pb_1(BaseBS): ...


class pb_2(BaseBS): ...


class pb_3(BaseBS): ...


class pb_4(BaseBS): ...


class pb_5(BaseBS): ...


class pb_lg_0(BaseBS): ...


class pb_lg_1(BaseBS): ...


class pb_lg_2(BaseBS): ...


class pb_lg_3(BaseBS): ...


class pb_lg_4(BaseBS): ...


class pb_lg_5(BaseBS): ...


class pb_md_0(BaseBS): ...


class pb_md_1(BaseBS): ...


class pb_md_2(BaseBS): ...


class pb_md_3(BaseBS): ...


class pb_md_4(BaseBS): ...


class pb_md_5(BaseBS): ...


class pb_sm_0(BaseBS): ...


class pb_sm_1(BaseBS): ...


class pb_sm_2(BaseBS): ...


class pb_sm_3(BaseBS): ...


class pb_sm_4(BaseBS): ...


class pb_sm_5(BaseBS): ...


class pb_xl_0(BaseBS): ...


class pb_xl_1(BaseBS): ...


class pb_xl_2(BaseBS): ...


class pb_xl_3(BaseBS): ...


class pb_xl_4(BaseBS): ...


class pb_xl_5(BaseBS): ...


class pb_xxl_0(BaseBS): ...


class pb_xxl_1(BaseBS): ...


class pb_xxl_2(BaseBS): ...


class pb_xxl_3(BaseBS): ...


class pb_xxl_4(BaseBS): ...


class pb_xxl_5(BaseBS): ...


class pe_0(BaseBS): ...


class pe_1(BaseBS): ...


class pe_2(BaseBS): ...


class pe_3(BaseBS): ...


class pe_4(BaseBS): ...


class pe_5(BaseBS): ...


class pe_auto(BaseBS): ...


class pe_lg_0(BaseBS): ...


class pe_lg_1(BaseBS): ...


class pe_lg_2(BaseBS): ...


class pe_lg_3(BaseBS): ...


class pe_lg_4(BaseBS): ...


class pe_lg_5(BaseBS): ...


class pe_md_0(BaseBS): ...


class pe_md_1(BaseBS): ...


class pe_md_2(BaseBS): ...


class pe_md_3(BaseBS): ...


class pe_md_4(BaseBS): ...


class pe_md_5(BaseBS): ...


class pe_none(BaseBS): ...


class pe_sm_0(BaseBS): ...


class pe_sm_1(BaseBS): ...


class pe_sm_2(BaseBS): ...


class pe_sm_3(BaseBS): ...


class pe_sm_4(BaseBS): ...


class pe_sm_5(BaseBS): ...


class pe_xl_0(BaseBS): ...


class pe_xl_1(BaseBS): ...


class pe_xl_2(BaseBS): ...


class pe_xl_3(BaseBS): ...


class pe_xl_4(BaseBS): ...


class pe_xl_5(BaseBS): ...


class pe_xxl_0(BaseBS): ...


class pe_xxl_1(BaseBS): ...


class pe_xxl_2(BaseBS): ...


class pe_xxl_3(BaseBS): ...


class pe_xxl_4(BaseBS): ...


class pe_xxl_5(BaseBS): ...


class placeholder(BaseBS): ...


class placeholder_glow(BaseBS): ...


class placeholder_lg(BaseBS): ...


class placeholder_sm(BaseBS): ...


class placeholder_wave(BaseBS): ...


class placeholder_xs(BaseBS): ...


class pointer_event(BaseBS): ...


class popover(BaseBS): ...


class popover_arrow(BaseBS): ...


class popover_body(BaseBS): ...


class popover_header(BaseBS): ...


class position_absolute(BaseBS): ...


class position_fixed(BaseBS): ...


class position_relative(BaseBS): ...


class position_static(BaseBS): ...


class position_sticky(BaseBS): ...


class progress(BaseBS): ...


class progress_bar(BaseBS): ...


class progress_bar_animated(BaseBS): ...


class progress_bar_striped(BaseBS): ...


class ps_0(BaseBS): ...


class ps_1(BaseBS): ...


class ps_2(BaseBS): ...


class ps_3(BaseBS): ...


class ps_4(BaseBS): ...


class ps_5(BaseBS): ...


class ps_lg_0(BaseBS): ...


class ps_lg_1(BaseBS): ...


class ps_lg_2(BaseBS): ...


class ps_lg_3(BaseBS): ...


class ps_lg_4(BaseBS): ...


class ps_lg_5(BaseBS): ...


class ps_md_0(BaseBS): ...


class ps_md_1(BaseBS): ...


class ps_md_2(BaseBS): ...


class ps_md_3(BaseBS): ...


class ps_md_4(BaseBS): ...


class ps_md_5(BaseBS): ...


class ps_sm_0(BaseBS): ...


class ps_sm_1(BaseBS): ...


class ps_sm_2(BaseBS): ...


class ps_sm_3(BaseBS): ...


class ps_sm_4(BaseBS): ...


class ps_sm_5(BaseBS): ...


class ps_xl_0(BaseBS): ...


class ps_xl_1(BaseBS): ...


class ps_xl_2(BaseBS): ...


class ps_xl_3(BaseBS): ...


class ps_xl_4(BaseBS): ...


class ps_xl_5(BaseBS): ...


class ps_xxl_0(BaseBS): ...


class ps_xxl_1(BaseBS): ...


class ps_xxl_2(BaseBS): ...


class ps_xxl_3(BaseBS): ...


class ps_xxl_4(BaseBS): ...


class ps_xxl_5(BaseBS): ...


class pt_0(BaseBS): ...


class pt_1(BaseBS): ...


class pt_2(BaseBS): ...


class pt_3(BaseBS): ...


class pt_4(BaseBS): ...


class pt_5(BaseBS): ...


class pt_lg_0(BaseBS): ...


class pt_lg_1(BaseBS): ...


class pt_lg_2(BaseBS): ...


class pt_lg_3(BaseBS): ...


class pt_lg_4(BaseBS): ...


class pt_lg_5(BaseBS): ...


class pt_md_0(BaseBS): ...


class pt_md_1(BaseBS): ...


class pt_md_2(BaseBS): ...


class pt_md_3(BaseBS): ...


class pt_md_4(BaseBS): ...


class pt_md_5(BaseBS): ...


class pt_sm_0(BaseBS): ...


class pt_sm_1(BaseBS): ...


class pt_sm_2(BaseBS): ...


class pt_sm_3(BaseBS): ...


class pt_sm_4(BaseBS): ...


class pt_sm_5(BaseBS): ...


class pt_xl_0(BaseBS): ...


class pt_xl_1(BaseBS): ...


class pt_xl_2(BaseBS): ...


class pt_xl_3(BaseBS): ...


class pt_xl_4(BaseBS): ...


class pt_xl_5(BaseBS): ...


class pt_xxl_0(BaseBS): ...


class pt_xxl_1(BaseBS): ...


class pt_xxl_2(BaseBS): ...


class pt_xxl_3(BaseBS): ...


class pt_xxl_4(BaseBS): ...


class pt_xxl_5(BaseBS): ...


class px_0(BaseBS): ...


class px_1(BaseBS): ...


class px_2(BaseBS): ...


class px_3(BaseBS): ...


class px_4(BaseBS): ...


class px_5(BaseBS): ...


class px_lg_0(BaseBS): ...


class px_lg_1(BaseBS): ...


class px_lg_2(BaseBS): ...


class px_lg_3(BaseBS): ...


class px_lg_4(BaseBS): ...


class px_lg_5(BaseBS): ...


class px_md_0(BaseBS): ...


class px_md_1(BaseBS): ...


class px_md_2(BaseBS): ...


class px_md_3(BaseBS): ...


class px_md_4(BaseBS): ...


class px_md_5(BaseBS): ...


class px_sm_0(BaseBS): ...


class px_sm_1(BaseBS): ...


class px_sm_2(BaseBS): ...


class px_sm_3(BaseBS): ...


class px_sm_4(BaseBS): ...


class px_sm_5(BaseBS): ...


class px_xl_0(BaseBS): ...


class px_xl_1(BaseBS): ...


class px_xl_2(BaseBS): ...


class px_xl_3(BaseBS): ...


class px_xl_4(BaseBS): ...


class px_xl_5(BaseBS): ...


class px_xxl_0(BaseBS): ...


class px_xxl_1(BaseBS): ...


class px_xxl_2(BaseBS): ...


class px_xxl_3(BaseBS): ...


class px_xxl_4(BaseBS): ...


class px_xxl_5(BaseBS): ...


class py_0(BaseBS): ...


class py_1(BaseBS): ...


class py_2(BaseBS): ...


class py_3(BaseBS): ...


class py_4(BaseBS): ...


class py_5(BaseBS): ...


class py_lg_0(BaseBS): ...


class py_lg_1(BaseBS): ...


class py_lg_2(BaseBS): ...


class py_lg_3(BaseBS): ...


class py_lg_4(BaseBS): ...


class py_lg_5(BaseBS): ...


class py_md_0(BaseBS): ...


class py_md_1(BaseBS): ...


class py_md_2(BaseBS): ...


class py_md_3(BaseBS): ...


class py_md_4(BaseBS): ...


class py_md_5(BaseBS): ...


class py_sm_0(BaseBS): ...


class py_sm_1(BaseBS): ...


class py_sm_2(BaseBS): ...


class py_sm_3(BaseBS): ...


class py_sm_4(BaseBS): ...


class py_sm_5(BaseBS): ...


class py_xl_0(BaseBS): ...


class py_xl_1(BaseBS): ...


class py_xl_2(BaseBS): ...


class py_xl_3(BaseBS): ...


class py_xl_4(BaseBS): ...


class py_xl_5(BaseBS): ...


class py_xxl_0(BaseBS): ...


class py_xxl_1(BaseBS): ...


class py_xxl_2(BaseBS): ...


class py_xxl_3(BaseBS): ...


class py_xxl_4(BaseBS): ...


class py_xxl_5(BaseBS): ...


class ratio(BaseBS): ...


class ratio_16x9(BaseBS): ...


class ratio_1x1(BaseBS): ...


class ratio_21x9(BaseBS): ...


class ratio_4x3(BaseBS): ...


class rounded(BaseBS): ...


class rounded_0(BaseBS): ...


class rounded_1(BaseBS): ...


class rounded_2(BaseBS): ...


class rounded_3(BaseBS): ...


class rounded_bottom(BaseBS): ...


class rounded_circle(BaseBS): ...


class rounded_end(BaseBS): ...


class rounded_pill(BaseBS): ...


class rounded_start(BaseBS): ...


class rounded_top(BaseBS): ...


class row(BaseBS): ...


class row_cols_1(BaseBS): ...


class row_cols_2(BaseBS): ...


class row_cols_3(BaseBS): ...


class row_cols_4(BaseBS): ...


class row_cols_5(BaseBS): ...


class row_cols_6(BaseBS): ...


class row_cols_auto(BaseBS): ...


class row_cols_lg_1(BaseBS): ...


class row_cols_lg_2(BaseBS): ...


class row_cols_lg_3(BaseBS): ...


class row_cols_lg_4(BaseBS): ...


class row_cols_lg_5(BaseBS): ...


class row_cols_lg_6(BaseBS): ...


class row_cols_lg_auto(BaseBS): ...


class row_cols_md_1(BaseBS): ...


class row_cols_md_2(BaseBS): ...


class row_cols_md_3(BaseBS): ...


class row_cols_md_4(BaseBS): ...


class row_cols_md_5(BaseBS): ...


class row_cols_md_6(BaseBS): ...


class row_cols_md_auto(BaseBS): ...


class row_cols_sm_1(BaseBS): ...


class row_cols_sm_2(BaseBS): ...


class row_cols_sm_3(BaseBS): ...


class row_cols_sm_4(BaseBS): ...


class row_cols_sm_5(BaseBS): ...


class row_cols_sm_6(BaseBS): ...


class row_cols_sm_auto(BaseBS): ...


class row_cols_xl_1(BaseBS): ...


class row_cols_xl_2(BaseBS): ...


class row_cols_xl_3(BaseBS): ...


class row_cols_xl_4(BaseBS): ...


class row_cols_xl_5(BaseBS): ...


class row_cols_xl_6(BaseBS): ...


class row_cols_xl_auto(BaseBS): ...


class row_cols_xxl_1(BaseBS): ...


class row_cols_xxl_2(BaseBS): ...


class row_cols_xxl_3(BaseBS): ...


class row_cols_xxl_4(BaseBS): ...


class row_cols_xxl_5(BaseBS): ...


class row_cols_xxl_6(BaseBS): ...


class row_cols_xxl_auto(BaseBS): ...


class shadow(BaseBS): ...


class shadow_lg(BaseBS): ...


class shadow_none(BaseBS): ...


class shadow_sm(BaseBS): ...


class show(BaseBS): ...


class showing(BaseBS): ...


class small(BaseBS): ...


class spinner_border(BaseBS): ...


class spinner_border_sm(BaseBS): ...


class spinner_grow(BaseBS): ...


class spinner_grow_sm(BaseBS): ...


class start_0(BaseBS): ...


class start_100(BaseBS): ...


class start_50(BaseBS): ...


class sticky_lg_top(BaseBS): ...


class sticky_md_top(BaseBS): ...


class sticky_sm_top(BaseBS): ...


class sticky_top(BaseBS): ...


class sticky_xl_top(BaseBS): ...


class sticky_xxl_top(BaseBS): ...


class stretched_link(BaseBS): ...


class tab_content(BaseBS): ...


class tab_pane(BaseBS): ...


class table(BaseBS): ...


class table_active(BaseBS): ...


class table_bordered(BaseBS): ...


class table_borderless(BaseBS): ...


class table_danger(BaseBS): ...


class table_dark(BaseBS): ...


class table_hover(BaseBS): ...


class table_info(BaseBS): ...


class table_light(BaseBS): ...


class table_primary(BaseBS): ...


class table_responsive(BaseBS): ...


class table_responsive_lg(BaseBS): ...


class table_responsive_md(BaseBS): ...


class table_responsive_sm(BaseBS): ...


class table_responsive_xl(BaseBS): ...


class table_responsive_xxl(BaseBS): ...


class table_secondary(BaseBS): ...


class table_sm(BaseBS): ...


class table_striped(BaseBS): ...


class table_success(BaseBS): ...


class table_warning(BaseBS): ...


class text_black(BaseBS): ...


class text_black_50(BaseBS): ...


class text_body(BaseBS): ...


class text_break(BaseBS): ...


class text_capitalize(BaseBS): ...


class text_center(BaseBS): ...


class text_danger(BaseBS): ...


class text_dark(BaseBS): ...


class text_decoration_line_through(BaseBS): ...


class text_decoration_none(BaseBS): ...


class text_decoration_underline(BaseBS): ...


class text_end(BaseBS): ...


class text_info(BaseBS): ...


class text_lg_center(BaseBS): ...


class text_lg_end(BaseBS): ...


class text_lg_start(BaseBS): ...


class text_light(BaseBS): ...


class text_lowercase(BaseBS): ...


class text_md_center(BaseBS): ...


class text_md_end(BaseBS): ...


class text_md_start(BaseBS): ...


class text_muted(BaseBS): ...


class text_nowrap(BaseBS): ...


class text_opacity_100(BaseBS): ...


class text_opacity_25(BaseBS): ...


class text_opacity_50(BaseBS): ...


class text_opacity_75(BaseBS): ...


class text_primary(BaseBS): ...


class text_reset(BaseBS): ...


class text_secondary(BaseBS): ...


class text_sm_center(BaseBS): ...


class text_sm_end(BaseBS): ...


class text_sm_start(BaseBS): ...


class text_start(BaseBS): ...


class text_success(BaseBS): ...


class text_truncate(BaseBS): ...


class text_uppercase(BaseBS): ...


class text_warning(BaseBS): ...


class text_white(BaseBS): ...


class text_white_50(BaseBS): ...


class text_wrap(BaseBS): ...


class text_xl_center(BaseBS): ...


class text_xl_end(BaseBS): ...


class text_xl_start(BaseBS): ...


class text_xxl_center(BaseBS): ...


class text_xxl_end(BaseBS): ...


class text_xxl_start(BaseBS): ...


class toast(BaseBS): ...


class toast_body(BaseBS): ...


class toast_container(BaseBS): ...


class toast_header(BaseBS): ...


class tooltip(BaseBS): ...


class tooltip_arrow(BaseBS): ...


class tooltip_inner(BaseBS): ...


class top_0(BaseBS): ...


class top_100(BaseBS): ...


class top_50(BaseBS): ...


class translate_middle(BaseBS): ...


class translate_middle_x(BaseBS): ...


class translate_middle_y(BaseBS): ...


class user_select_all(BaseBS): ...


class user_select_auto(BaseBS): ...


class user_select_none(BaseBS): ...


class valid_feedback(BaseBS): ...


class valid_tooltip(BaseBS): ...


class vh_100(BaseBS): ...


class visible(BaseBS): ...


class visually_hidden(BaseBS): ...


class visually_hidden_focusable(BaseBS): ...


class vr(BaseBS): ...


class vstack(BaseBS): ...


class vw_100(BaseBS): ...


class w_100(BaseBS): ...


class w_25(BaseBS): ...


class w_50(BaseBS): ...


class w_75(BaseBS): ...


class w_auto(BaseBS): ...


class was_validated(BaseBS): ...
