import json
from typing import Any, Optional

from inui.base import BaseVoidElement
from inui.conf import TAILWINDCSS_CONFIG, TAILWINDCSS_CUSTOM_CSS, TAILWINDCSS_URL
from inui.elements import Script, Style
from inui.tailwind.utils import tw_class_to_lower


class TailwindCSS(BaseVoidElement):

    def __init__(
        self,
        *data: Any,
        url: str = TAILWINDCSS_URL,
        config: dict = TAILWINDCSS_CONFIG,
        customcss: str = TAILWINDCSS_CUSTOM_CSS,
        **attributes: Any
    ) -> None:
        self.url = url
        self.config = config
        self.customcss = customcss
        super().__init__(*data, **attributes)

    def render(self, prettify: bool = False):
        return (
            Script(src=self.url).render()
            + (
                Script(f"tailwind.config={json.dumps(self.config)}").render()
                if self.config
                else ""
            )
            + (
                Style(self.customcss, type_="text_tailwindcss").render()
                if self.customcss
                else ""
            )
        )


class BaseTW(BaseVoidElement):
    tag: Optional[str] = None

    def __init__(self, *values) -> None:
        self.values = values

    def render(self, prettify: bool = False) -> str:
        values = ""
        if self.values:
            values += " -"
            values += "-".join(list(map(str, self.values)))
        return self.tag or tw_class_to_lower(self.__class__.__name__) + values


class ease_linear(BaseTW): ...


class ease(BaseTW): ...


class duration(BaseTW): ...


class duration_75(BaseTW): ...


class duration_100(BaseTW): ...


class duration_150(BaseTW): ...


class duration_200(BaseTW): ...


class duration_300(BaseTW): ...


class duration_500(BaseTW): ...


class duration_700(BaseTW): ...


class duration_1000(BaseTW): ...


class delay(BaseTW): ...


class delay_75(BaseTW): ...


class delay_100(BaseTW): ...


class delay_150(BaseTW): ...


class delay_200(BaseTW): ...


class delay_300(BaseTW): ...


class delay_500(BaseTW): ...


class delay_700(BaseTW): ...


class delay_1000(BaseTW): ...


class transition(BaseTW): ...


class animate(BaseTW): ...


class animate_bounce(BaseTW): ...


class animate_none(BaseTW): ...


class animate_ping(BaseTW): ...


class animate_pulse(BaseTW): ...


class animate_spin(BaseTW): ...


class bg(BaseTW): ...


class bg_auto(BaseTW): ...


class bg_cover(BaseTW): ...


class bg_contain(BaseTW): ...


class bg_bottom(BaseTW): ...


class bg_top(BaseTW): ...


class bg_center(BaseTW): ...


class bg_left(BaseTW): ...


class bg_left_bottom(BaseTW): ...


class bg_left_top(BaseTW): ...


class bg_right(BaseTW): ...


class bg_right_bottom(BaseTW): ...


class bg_right_top(BaseTW): ...


class bg_fixed(BaseTW): ...


class bg_local(BaseTW): ...


class bg_scroll(BaseTW): ...


class bg_no_repeat(BaseTW): ...


class bg_repeat(BaseTW): ...


class bg_repeat_x(BaseTW): ...


class bg_repeat_y(BaseTW): ...


class bg_repeat_round(BaseTW): ...


class bg_repeat_space(BaseTW): ...


class bg_opacity_0(BaseTW): ...


class bg_opacity_25(BaseTW): ...


class bg_opacity_50(BaseTW): ...


class bg_opacity_75(BaseTW): ...


class bg_opacity_100(BaseTW): ...


class bg_none(BaseTW): ...


class bg_clip(BaseTW): ...


class bg_clip_border(BaseTW): ...


class bg_clip_content(BaseTW): ...


class bg_clip_padding(BaseTW): ...


class bg_clip_text(BaseTW): ...


class bg_transparent(BaseTW): ...


class bg_current(BaseTW): ...


class bg_black(BaseTW): ...


class bg_white(BaseTW): ...


class bg_gray(BaseTW): ...


class bg_gray_100(BaseTW): ...


class bg_gray_200(BaseTW): ...


class bg_gray_300(BaseTW): ...


class bg_gray_400(BaseTW): ...


class bg_gray_500(BaseTW): ...


class bg_gray_600(BaseTW): ...


class bg_gray_700(BaseTW): ...


class bg_gray_800(BaseTW): ...


class bg_gray_900(BaseTW): ...


class bg_red(BaseTW): ...


class bg_red_100(BaseTW): ...


class bg_red_200(BaseTW): ...


class bg_red_300(BaseTW): ...


class bg_red_400(BaseTW): ...


class bg_red_500(BaseTW): ...


class bg_red_600(BaseTW): ...


class bg_red_700(BaseTW): ...


class bg_red_800(BaseTW): ...


class bg_red_900(BaseTW): ...


class bg_orange_100(BaseTW): ...


class bg_orange_200(BaseTW): ...


class bg_orange_300(BaseTW): ...


class bg_orange_400(BaseTW): ...


class bg_orange_500(BaseTW): ...


class bg_orange_600(BaseTW): ...


class bg_orange_700(BaseTW): ...


class bg_orange_800(BaseTW): ...


class bg_orange_900(BaseTW): ...


class bg_yellow_100(BaseTW): ...


class bg_yellow_200(BaseTW): ...


class bg_yellow_300(BaseTW): ...


class bg_yellow_400(BaseTW): ...


class bg_yellow_500(BaseTW): ...


class bg_yellow_600(BaseTW): ...


class bg_yellow_700(BaseTW): ...


class bg_yellow_800(BaseTW): ...


class bg_yellow_900(BaseTW): ...


class bg_green_100(BaseTW): ...


class bg_green_200(BaseTW): ...


class bg_green_300(BaseTW): ...


class bg_green_400(BaseTW): ...


class bg_green_500(BaseTW): ...


class bg_green_600(BaseTW): ...


class bg_green_700(BaseTW): ...


class bg_green_800(BaseTW): ...


class bg_green_900(BaseTW): ...


class bg_teal_100(BaseTW): ...


class bg_teal_200(BaseTW): ...


class bg_teal_300(BaseTW): ...


class bg_teal_400(BaseTW): ...


class bg_teal_500(BaseTW): ...


class bg_teal_600(BaseTW): ...


class bg_teal_700(BaseTW): ...


class bg_teal_800(BaseTW): ...


class bg_teal_900(BaseTW): ...


class bg_blue_100(BaseTW): ...


class bg_blue_200(BaseTW): ...


class bg_blue_300(BaseTW): ...


class bg_blue_400(BaseTW): ...


class bg_blue_500(BaseTW): ...


class bg_blue_600(BaseTW): ...


class bg_blue_700(BaseTW): ...


class bg_blue_800(BaseTW): ...


class bg_blue_900(BaseTW): ...


class bg_indigo_100(BaseTW): ...


class bg_indigo_200(BaseTW): ...


class bg_indigo_300(BaseTW): ...


class bg_indigo_400(BaseTW): ...


class bg_indigo_500(BaseTW): ...


class bg_indigo_600(BaseTW): ...


class bg_indigo_700(BaseTW): ...


class bg_indigo_800(BaseTW): ...


class bg_indigo_900(BaseTW): ...


class bg_purple_100(BaseTW): ...


class bg_purple_200(BaseTW): ...


class bg_purple_300(BaseTW): ...


class bg_purple_400(BaseTW): ...


class bg_purple_500(BaseTW): ...


class bg_purple_600(BaseTW): ...


class bg_purple_700(BaseTW): ...


class bg_purple_800(BaseTW): ...


class bg_purple_900(BaseTW): ...


class bg_pink_100(BaseTW): ...


class bg_pink_200(BaseTW): ...


class bg_pink_300(BaseTW): ...


class bg_pink_400(BaseTW): ...


class bg_pink_500(BaseTW): ...


class bg_pink_600(BaseTW): ...


class bg_pink_700(BaseTW): ...


class bg_pink_800(BaseTW): ...


class bg_pink_900(BaseTW): ...


class bg_gradient_to_b(BaseTW): ...


class bg_gradient_to_bl(BaseTW): ...


class bg_gradient_to_br(BaseTW): ...


class bg_gradient_to_l(BaseTW): ...


class bg_gradient_to_r(BaseTW): ...


class bg_gradient_to_t(BaseTW): ...


class bg_gradient_to_tl(BaseTW): ...


class bg_gradient_to_tr(BaseTW): ...


class from_blue_100(BaseTW): ...


class from_current(BaseTW): ...


class from_gray_100(BaseTW): ...


class from_indigo_100(BaseTW): ...


class from_pink_100(BaseTW): ...


class from_purple_100(BaseTW): ...


class from_red_100(BaseTW): ...


class from_transparent(BaseTW): ...


class from_white(BaseTW): ...


class from_yellow_100(BaseTW): ...


class to_black(BaseTW): ...


class to_blue_100(BaseTW): ...


class to_current(BaseTW): ...


class to_gray_100(BaseTW): ...


class to_green_100(BaseTW): ...


class to_indigo_100(BaseTW): ...


class to_pink_100(BaseTW): ...


class to_purple_100(BaseTW): ...


class to_red_100(BaseTW): ...


class to_transparent(BaseTW): ...


class to_white(BaseTW): ...


class to_yellow_100(BaseTW): ...


class top_1(BaseTW): ...


class via_black(BaseTW): ...


class via_blue_100(BaseTW): ...


class via_current(BaseTW): ...


class via_gray_100(BaseTW): ...


class via_green_100(BaseTW): ...


class via_indigo_100(BaseTW): ...


class via_pink_100(BaseTW): ...


class via_purple_100(BaseTW): ...


class via_red_100(BaseTW): ...


class via_transparent(BaseTW): ...


class via_white(BaseTW): ...


class via_yellow_100(BaseTW): ...


class border_transparent(BaseTW): ...


class border_current(BaseTW): ...


class border_black(BaseTW): ...


class border_white(BaseTW): ...


class border_gray_100(BaseTW): ...


class border_gray_200(BaseTW): ...


class border_gray_300(BaseTW): ...


class border_gray_400(BaseTW): ...


class border_gray_500(BaseTW): ...


class border_gray_600(BaseTW): ...


class border_gray_700(BaseTW): ...


class border_gray_800(BaseTW): ...


class border_gray_900(BaseTW): ...


class border_red_100(BaseTW): ...


class border_red_200(BaseTW): ...


class border_red_300(BaseTW): ...


class border_red_400(BaseTW): ...


class border_red_500(BaseTW): ...


class border_red_600(BaseTW): ...


class border_red_700(BaseTW): ...


class border_red_800(BaseTW): ...


class border_red_900(BaseTW): ...


class border_orange_100(BaseTW): ...


class border_orange_200(BaseTW): ...


class border_orange_300(BaseTW): ...


class border_orange_400(BaseTW): ...


class border_orange_500(BaseTW): ...


class border_orange_600(BaseTW): ...


class border_orange_700(BaseTW): ...


class border_orange_800(BaseTW): ...


class border_orange_900(BaseTW): ...


class border_yellow_100(BaseTW): ...


class border_yellow_200(BaseTW): ...


class border_yellow_300(BaseTW): ...


class border_yellow_400(BaseTW): ...


class border_yellow_500(BaseTW): ...


class border_yellow_600(BaseTW): ...


class border_yellow_700(BaseTW): ...


class border_yellow_800(BaseTW): ...


class border_yellow_900(BaseTW): ...


class border_green_100(BaseTW): ...


class border_green_200(BaseTW): ...


class border_green_300(BaseTW): ...


class border_green_400(BaseTW): ...


class border_green_500(BaseTW): ...


class border_green_600(BaseTW): ...


class border_green_700(BaseTW): ...


class border_green_800(BaseTW): ...


class border_green_900(BaseTW): ...


class border_teal_100(BaseTW): ...


class border_teal_200(BaseTW): ...


class border_teal_300(BaseTW): ...


class border_teal_400(BaseTW): ...


class border_teal_500(BaseTW): ...


class border_teal_600(BaseTW): ...


class border_teal_700(BaseTW): ...


class border_teal_800(BaseTW): ...


class border_teal_900(BaseTW): ...


class border_blue_100(BaseTW): ...


class border_blue_200(BaseTW): ...


class border_blue_300(BaseTW): ...


class border_blue_400(BaseTW): ...


class border_blue_500(BaseTW): ...


class border_blue_600(BaseTW): ...


class border_blue_700(BaseTW): ...


class border_blue_800(BaseTW): ...


class border_blue_900(BaseTW): ...


class border_indigo_100(BaseTW): ...


class border_indigo_200(BaseTW): ...


class border_indigo_300(BaseTW): ...


class border_indigo_400(BaseTW): ...


class border_indigo_500(BaseTW): ...


class border_indigo_600(BaseTW): ...


class border_indigo_700(BaseTW): ...


class border_indigo_800(BaseTW): ...


class border_indigo_900(BaseTW): ...


class border_purple_100(BaseTW): ...


class border_purple_200(BaseTW): ...


class border_purple_300(BaseTW): ...


class border_purple_400(BaseTW): ...


class border_purple_500(BaseTW): ...


class border_purple_600(BaseTW): ...


class border_purple_700(BaseTW): ...


class border_purple_800(BaseTW): ...


class border_purple_900(BaseTW): ...


class border_pink_100(BaseTW): ...


class border_pink_200(BaseTW): ...


class border_pink_300(BaseTW): ...


class border_pink_400(BaseTW): ...


class border_pink_500(BaseTW): ...


class border_pink_600(BaseTW): ...


class border_pink_700(BaseTW): ...


class border_pink_800(BaseTW): ...


class border_pink_900(BaseTW): ...


class border_solid(BaseTW): ...


class border_dashed(BaseTW): ...


class border_dotted(BaseTW): ...


class border_double(BaseTW): ...


class border_none(BaseTW): ...


class border(BaseTW): ...


class border_0(BaseTW): ...


class border_2(BaseTW): ...


class border_4(BaseTW): ...


class border_8(BaseTW): ...


class border_t_2(BaseTW): ...


class border_opacity_25(BaseTW): ...


class divide_x(BaseTW): ...


class divide_x_0(BaseTW): ...


class divide_x_2(BaseTW): ...


class divide_x_4(BaseTW): ...


class divide_x_8(BaseTW): ...


class divide_y(BaseTW): ...


class divide_y_0(BaseTW): ...


class divide_y_2(BaseTW): ...


class divide_y_4(BaseTW): ...


class divide_y_8(BaseTW): ...


class divide_gray_100(BaseTW): ...


class divide(BaseTW): ...


class divide_x_reverse(BaseTW): ...


class divide_opacity_25(BaseTW): ...


class divide_opacity(BaseTW): ...


class border_collapse(BaseTW): ...


class border_separate(BaseTW): ...


class rounded(BaseTW): ...


class border_b(BaseTW): ...


class border_b_0(BaseTW): ...


class border_blue_50(BaseTW): ...


class border_gray_50(BaseTW): ...


class border_green_50(BaseTW): ...


class border_indigo_50(BaseTW): ...


class border_l(BaseTW): ...


class border_l_0(BaseTW): ...


class border_opacity_0(BaseTW): ...


class border_pink_50(BaseTW): ...


class border_purple_50(BaseTW): ...


class border_r(BaseTW): ...


class border_r_0(BaseTW): ...


class border_red_50(BaseTW): ...


class border_t(BaseTW): ...


class border_t_0(BaseTW): ...


class border_yellow_50(BaseTW): ...


class rounded_2xl(BaseTW): ...


class rounded_3xl(BaseTW): ...


class rounded_b_2xl(BaseTW): ...


class rounded_b_3xl(BaseTW): ...


class rounded_b_xl(BaseTW): ...


class rounded_bl_2xl(BaseTW): ...


class rounded_bl_3xl(BaseTW): ...


class rounded_bl_xl(BaseTW): ...


class rounded_br_2xl(BaseTW): ...


class rounded_br_3xl(BaseTW): ...


class rounded_br_xl(BaseTW): ...


class rounded_l_2xl(BaseTW): ...


class rounded_l_xl(BaseTW): ...


class rounded_r_2xl(BaseTW): ...


class rounded_r_3xl(BaseTW): ...


class rounded_r_xl(BaseTW): ...


class rounded_t_2xl(BaseTW): ...


class rounded_t_3xl(BaseTW): ...


class rounded_t_xl(BaseTW): ...


class rounded_tl_2xl(BaseTW): ...


class rounded_tl_3xl(BaseTW): ...


class rounded_tl_xl(BaseTW): ...


class rounded_tr_2xl(BaseTW): ...


class rounded_tr_3xl(BaseTW): ...


class rounded_tr_xl(BaseTW): ...


class rounded_xl(BaseTW): ...


class box_border(BaseTW): ...


class box_content(BaseTW): ...


class bg_blue_50(BaseTW): ...


class bg_gray_50(BaseTW): ...


class bg_green_50(BaseTW): ...


class bg_indigo_50(BaseTW): ...


class bg_opacity_10(BaseTW): ...


class bg_pink_50(BaseTW): ...


class bg_purple_50(BaseTW): ...


class bg_red_50(BaseTW): ...


class bg_yellow_50(BaseTW): ...


class block(BaseTW): ...


class hidden(BaseTW): ...


class inline(BaseTW): ...


class inline_block(BaseTW): ...


class inline_flex(BaseTW): ...


class inline_grid(BaseTW): ...


class flex(BaseTW): ...


class grid(BaseTW): ...


class flow_root(BaseTW): ...


class divide_black(BaseTW): ...


class divide_blue_100(BaseTW): ...


class divide_current(BaseTW): ...


class divide_dashed(BaseTW): ...


class divide_dotted(BaseTW): ...


class divide_doubble(BaseTW): ...


class divide_green_100(BaseTW): ...


class divide_indigo_100(BaseTW): ...


class divide_none(BaseTW): ...


class divide_opacity_0(BaseTW): ...


class divide_pink_100(BaseTW): ...


class divide_purple_100(BaseTW): ...


class divide_red_100(BaseTW): ...


class divide_solid(BaseTW): ...


class divide_transparent(BaseTW): ...


class divide_white(BaseTW): ...


class divide_y_reverse(BaseTW): ...


class divide_yellow_100(BaseTW): ...


class flex_row(BaseTW): ...


class flex_row_reverse(BaseTW): ...


class flex_col(BaseTW): ...


class flex_col_reverse(BaseTW): ...


class flex_initial(BaseTW): ...


class flex_1(BaseTW): ...


class flex_auto(BaseTW): ...


class flex_none(BaseTW): ...


class flex_no_wrap(BaseTW): ...


class flex_wrap(BaseTW): ...


class flex_wrap_reverse(BaseTW): ...


class items_stretch(BaseTW): ...


class items(BaseTW): ...


class content_start(BaseTW): ...


class content(BaseTW): ...


class justify_start(BaseTW): ...


class justify(BaseTW): ...


class self_start(BaseTW): ...


class self(BaseTW): ...


class flex_grow(BaseTW): ...


class flex_grow_0(BaseTW): ...


class flex_shrink(BaseTW): ...


class flex_shrink_0(BaseTW): ...


class order_1(BaseTW): ...


class order(BaseTW): ...


class content_around(BaseTW): ...


class content_between(BaseTW): ...


class content_center(BaseTW): ...


class content_end(BaseTW): ...


class content_evenly(BaseTW): ...


class contents(BaseTW): ...


class flex_nowrap(BaseTW): ...


class justify_items_auto(BaseTW): ...


class justify_items_center(BaseTW): ...


class justify_items_end(BaseTW): ...


class justify_items_start(BaseTW): ...


class justify_items_stretch(BaseTW): ...


class justify_self_auto(BaseTW): ...


class justify_self_center(BaseTW): ...


class justify_self_end(BaseTW): ...


class justify_self_start(BaseTW): ...


class justify_self_stretch(BaseTW): ...


class space_x_7(BaseTW): ...


class space_x_px(BaseTW): ...


class space_x_reverse(BaseTW): ...


class space_y_px(BaseTW): ...


class space_y_reverse(BaseTW): ...


class focus_within(BaseTW): ...


class from_black(BaseTW): ...


class col_auto(BaseTW): ...


class col_span_1(BaseTW): ...


class col_span(BaseTW): ...


class col_start_1(BaseTW): ...


class col_start(BaseTW): ...


class col_end_1(BaseTW): ...


class col_end(BaseTW): ...


class gap_0(BaseTW): ...


class gap(BaseTW): ...


class row_gap_0(BaseTW): ...


class row_gap(BaseTW): ...


class col_gap_0(BaseTW): ...


class col_gap(BaseTW): ...


class grid_rows_1(BaseTW): ...


class grid_rows(BaseTW): ...


class grid_cols_1(BaseTW): ...


class grid_cols(BaseTW): ...


class grid_flow_row(BaseTW): ...


class grid_flow_row_dense(BaseTW): ...


class grid_flow_col(BaseTW): ...


class grid_flow_col_dense(BaseTW): ...


class row_span_1(BaseTW): ...


class row_span(BaseTW): ...


class row_start_auto(BaseTW): ...


class row_start_1(BaseTW): ...


class row_start_2(BaseTW): ...


class row_start_3(BaseTW): ...


class row_start_4(BaseTW): ...


class row_start_5(BaseTW): ...


class row_start_6(BaseTW): ...


class row_start_7(BaseTW): ...


class row_end_auto(BaseTW): ...


class row_end_1(BaseTW): ...


class row_end_2(BaseTW): ...


class row_end_3(BaseTW): ...


class row_end_4(BaseTW): ...


class row_end_5(BaseTW): ...


class row_end_6(BaseTW): ...


class row_end_7(BaseTW): ...


class auto_cols_auto(BaseTW): ...


class auto_cols_fr(BaseTW): ...


class auto_cols_max(BaseTW): ...


class auto_cols_min(BaseTW): ...


class auto_rows_auto(BaseTW): ...


class auto_rows_fr(BaseTW): ...


class auto_rows_max(BaseTW): ...


class auto_rows_min(BaseTW): ...


class col_end_auto(BaseTW): ...


class col_span_full(BaseTW): ...


class col_start_auto(BaseTW): ...


class gap_px(BaseTW): ...


class gap_x_0(BaseTW): ...


class gap_x_px(BaseTW): ...


class gap_y_0(BaseTW): ...


class gap_y_px(BaseTW): ...


class place_content_around(BaseTW): ...


class place_content_between(BaseTW): ...


class place_content_center(BaseTW): ...


class place_content_end(BaseTW): ...


class place_content_evenly(BaseTW): ...


class place_content_start(BaseTW): ...


class place_content_stretch(BaseTW): ...


class place_items_auto(BaseTW): ...


class place_items_center(BaseTW): ...


class place_items_end(BaseTW): ...


class place_items_start(BaseTW): ...


class place_items_stretch(BaseTW): ...


class place_self_auto(BaseTW): ...


class place_self_end(BaseTW): ...


class place_self_start(BaseTW): ...


class place_self_stretch(BaseTW): ...


class row_auto(BaseTW): ...


class row_span_full(BaseTW): ...


class group_hover(BaseTW): ...


class h_0(BaseTW): ...


class h_1(BaseTW): ...


class h_2(BaseTW): ...


class h_3(BaseTW): ...


class h_4(BaseTW): ...


class h_5(BaseTW): ...


class h_6(BaseTW): ...


class h_8(BaseTW): ...


class h_10(BaseTW): ...


class h_12(BaseTW): ...


class h_16(BaseTW): ...


class h_20(BaseTW): ...


class h_24(BaseTW): ...


class h_32(BaseTW): ...


class h_40(BaseTW): ...


class h_48(BaseTW): ...


class h_56(BaseTW): ...


class h_64(BaseTW): ...


class h_auto(BaseTW): ...


class h_px(BaseTW): ...


class h_full(BaseTW): ...


class h_screen(BaseTW): ...


class max_h_full(BaseTW): ...


class max_h_screen(BaseTW): ...


class min_h_0(BaseTW): ...


class min_h_full(BaseTW): ...


class min_h_screen(BaseTW): ...


class max_h_px(BaseTW): ...


class list_disc(BaseTW): ...


class list(BaseTW): ...


class list_inside(BaseTW): ...


class list_outside(BaseTW): ...


class m_0(BaseTW): ...


class m_1(BaseTW): ...


class m_2(BaseTW): ...


class m_3(BaseTW): ...


class m_4(BaseTW): ...


class m_5(BaseTW): ...


class m_6(BaseTW): ...


class m_8(BaseTW): ...


class m_10(BaseTW): ...


class m_12(BaseTW): ...


class m_16(BaseTW): ...


class m_20(BaseTW): ...


class m_24(BaseTW): ...


class m_32(BaseTW): ...


class m_40(BaseTW): ...


class m_48(BaseTW): ...


class m_56(BaseTW): ...


class m_64(BaseTW): ...


class m_auto(BaseTW): ...


class m_px(BaseTW): ...


class mb_0(BaseTW): ...


class mb_1(BaseTW): ...


class mb_2(BaseTW): ...


class mb_3(BaseTW): ...


class mb_4(BaseTW): ...


class mb_5(BaseTW): ...


class mb_6(BaseTW): ...


class mb_8(BaseTW): ...


class mb_10(BaseTW): ...


class mb_12(BaseTW): ...


class mb_16(BaseTW): ...


class mb_20(BaseTW): ...


class mb_24(BaseTW): ...


class mb_32(BaseTW): ...


class mb_40(BaseTW): ...


class mb_48(BaseTW): ...


class mb_56(BaseTW): ...


class mb_64(BaseTW): ...


class mb_auto(BaseTW): ...


class mb_px(BaseTW): ...


class mr_0(BaseTW): ...


class mr_1(BaseTW): ...


class mr_2(BaseTW): ...


class mr_3(BaseTW): ...


class mr_4(BaseTW): ...


class mr_5(BaseTW): ...


class mr_6(BaseTW): ...


class mr_8(BaseTW): ...


class mr_10(BaseTW): ...


class mr_12(BaseTW): ...


class mr_16(BaseTW): ...


class mr_20(BaseTW): ...


class mr_24(BaseTW): ...


class mr_32(BaseTW): ...


class mr_40(BaseTW): ...


class mr_48(BaseTW): ...


class mr_56(BaseTW): ...


class mr_64(BaseTW): ...


class mr_auto(BaseTW): ...


class mr_px(BaseTW): ...


class mt_0(BaseTW): ...


class mt_1(BaseTW): ...


class mt_2(BaseTW): ...


class mt_3(BaseTW): ...


class mt_4(BaseTW): ...


class mt_5(BaseTW): ...


class mt_6(BaseTW): ...


class mt_8(BaseTW): ...


class mt_10(BaseTW): ...


class mt_12(BaseTW): ...


class mt_16(BaseTW): ...


class mt_20(BaseTW): ...


class mt_24(BaseTW): ...


class mt_32(BaseTW): ...


class mt_40(BaseTW): ...


class mt_48(BaseTW): ...


class mt_56(BaseTW): ...


class mt_64(BaseTW): ...


class mt_auto(BaseTW): ...


class mt_px(BaseTW): ...


class ml_0(BaseTW): ...


class ml_1(BaseTW): ...


class ml_2(BaseTW): ...


class ml_3(BaseTW): ...


class ml_4(BaseTW): ...


class ml_5(BaseTW): ...


class ml_6(BaseTW): ...


class ml_8(BaseTW): ...


class ml_10(BaseTW): ...


class ml_12(BaseTW): ...


class ml_16(BaseTW): ...


class ml_20(BaseTW): ...


class ml_24(BaseTW): ...


class ml_32(BaseTW): ...


class ml_40(BaseTW): ...


class ml_48(BaseTW): ...


class ml_56(BaseTW): ...


class ml_64(BaseTW): ...


class ml_auto(BaseTW): ...


class ml_px(BaseTW): ...


class mx_0(BaseTW): ...


class mx_1(BaseTW): ...


class mx_2(BaseTW): ...


class mx_3(BaseTW): ...


class mx_4(BaseTW): ...


class mx_5(BaseTW): ...


class mx_6(BaseTW): ...


class mx_8(BaseTW): ...


class mx_10(BaseTW): ...


class mx_12(BaseTW): ...


class mx_16(BaseTW): ...


class mx_20(BaseTW): ...


class mx_24(BaseTW): ...


class mx_32(BaseTW): ...


class mx_40(BaseTW): ...


class mx_48(BaseTW): ...


class mx_56(BaseTW): ...


class mx_64(BaseTW): ...


class mx_auto(BaseTW): ...


class mx_px(BaseTW): ...


class my_0(BaseTW): ...


class my_1(BaseTW): ...


class my_2(BaseTW): ...


class my_3(BaseTW): ...


class my_4(BaseTW): ...


class my_5(BaseTW): ...


class my_6(BaseTW): ...


class my_8(BaseTW): ...


class my_10(BaseTW): ...


class my_12(BaseTW): ...


class my_16(BaseTW): ...


class my_20(BaseTW): ...


class my_24(BaseTW): ...


class my_32(BaseTW): ...


class my_40(BaseTW): ...


class my_48(BaseTW): ...


class my_56(BaseTW): ...


class my_64(BaseTW): ...


class my_auto(BaseTW): ...


class my_px(BaseTW): ...


class _m_1(BaseTW): ...


class _m_2(BaseTW): ...


class _m_3(BaseTW): ...


class _m_4(BaseTW): ...


class _m_5(BaseTW): ...


class _m_6(BaseTW): ...


class _m_8(BaseTW): ...


class _m_10(BaseTW): ...


class _m_12(BaseTW): ...


class _m_16(BaseTW): ...


class _m_20(BaseTW): ...


class _m_24(BaseTW): ...


class _m_32(BaseTW): ...


class _m_40(BaseTW): ...


class _m_48(BaseTW): ...


class _m_56(BaseTW): ...


class _m_64(BaseTW): ...


class _m_px(BaseTW): ...


class _mb_1(BaseTW): ...


class _mb_2(BaseTW): ...


class _mb_3(BaseTW): ...


class _mb_4(BaseTW): ...


class _mb_5(BaseTW): ...


class _mb_6(BaseTW): ...


class _mb_8(BaseTW): ...


class _mb_10(BaseTW): ...


class _mb_12(BaseTW): ...


class _mb_16(BaseTW): ...


class _mb_20(BaseTW): ...


class _mb_24(BaseTW): ...


class _mb_32(BaseTW): ...


class _mb_40(BaseTW): ...


class _mb_48(BaseTW): ...


class _mb_56(BaseTW): ...


class _mb_64(BaseTW): ...


class _mb_px(BaseTW): ...


class _mr_1(BaseTW): ...


class _mr_2(BaseTW): ...


class _mr_3(BaseTW): ...


class _mr_4(BaseTW): ...


class _mr_5(BaseTW): ...


class _mr_6(BaseTW): ...


class _mr_8(BaseTW): ...


class _mr_10(BaseTW): ...


class _mr_12(BaseTW): ...


class _mr_16(BaseTW): ...


class _mr_20(BaseTW): ...


class _mr_24(BaseTW): ...


class _mr_32(BaseTW): ...


class _mr_40(BaseTW): ...


class _mr_48(BaseTW): ...


class _mr_56(BaseTW): ...


class _mr_64(BaseTW): ...


class _mr_px(BaseTW): ...


class _mt_1(BaseTW): ...


class _mt_2(BaseTW): ...


class _mt_3(BaseTW): ...


class _mt_4(BaseTW): ...


class _mt_5(BaseTW): ...


class _mt_6(BaseTW): ...


class _mt_8(BaseTW): ...


class _mt_10(BaseTW): ...


class _mt_12(BaseTW): ...


class _mt_16(BaseTW): ...


class _mt_20(BaseTW): ...


class _mt_24(BaseTW): ...


class _mt_32(BaseTW): ...


class _mt_40(BaseTW): ...


class _mt_48(BaseTW): ...


class _mt_56(BaseTW): ...


class _mt_64(BaseTW): ...


class _mt_px(BaseTW): ...


class _ml_1(BaseTW): ...


class _ml_2(BaseTW): ...


class _ml_3(BaseTW): ...


class _ml_4(BaseTW): ...


class _ml_5(BaseTW): ...


class _ml_6(BaseTW): ...


class _ml_8(BaseTW): ...


class _ml_10(BaseTW): ...


class _ml_12(BaseTW): ...


class _ml_16(BaseTW): ...


class _ml_20(BaseTW): ...


class _ml_24(BaseTW): ...


class _ml_32(BaseTW): ...


class _ml_40(BaseTW): ...


class _ml_48(BaseTW): ...


class _ml_56(BaseTW): ...


class _ml_64(BaseTW): ...


class _ml_px(BaseTW): ...


class _mx_1(BaseTW): ...


class _mx_2(BaseTW): ...


class _mx_3(BaseTW): ...


class _mx_4(BaseTW): ...


class _mx_5(BaseTW): ...


class _mx_6(BaseTW): ...


class _mx_8(BaseTW): ...


class _mx_10(BaseTW): ...


class _mx_12(BaseTW): ...


class _mx_16(BaseTW): ...


class _mx_20(BaseTW): ...


class _mx_24(BaseTW): ...


class _mx_32(BaseTW): ...


class _mx_40(BaseTW): ...


class _mx_48(BaseTW): ...


class _mx_56(BaseTW): ...


class _mx_64(BaseTW): ...


class _mx_px(BaseTW): ...


class _my_1(BaseTW): ...


class _my_2(BaseTW): ...


class _my_3(BaseTW): ...


class _my_4(BaseTW): ...


class _my_5(BaseTW): ...


class _my_6(BaseTW): ...


class _my_8(BaseTW): ...


class _my_10(BaseTW): ...


class _my_12(BaseTW): ...


class _my_16(BaseTW): ...


class _my_20(BaseTW): ...


class _my_24(BaseTW): ...


class _my_32(BaseTW): ...


class _my_40(BaseTW): ...


class _my_48(BaseTW): ...


class _my_56(BaseTW): ...


class _my_64(BaseTW): ...


class _my_px(BaseTW): ...


class mt_11(BaseTW): ...


class mb_11(BaseTW): ...


class ml_11(BaseTW): ...


class mr_11(BaseTW): ...


class mx_11(BaseTW): ...


class my_11(BaseTW): ...


class lining_nums(BaseTW): ...


class normal_nums(BaseTW): ...


class oldstyle_nums(BaseTW): ...


class stacked_fractions(BaseTW): ...


class opacity_10(BaseTW): ...


class outline_black(BaseTW): ...


class outline_white(BaseTW): ...


class p_0(BaseTW): ...


class p_1(BaseTW): ...


class p_2(BaseTW): ...


class p_3(BaseTW): ...


class p_4(BaseTW): ...


class p_5(BaseTW): ...


class p_6(BaseTW): ...


class p_8(BaseTW): ...


class p_10(BaseTW): ...


class p_12(BaseTW): ...


class p_16(BaseTW): ...


class p_20(BaseTW): ...


class p_24(BaseTW): ...


class p_32(BaseTW): ...


class p_40(BaseTW): ...


class p_48(BaseTW): ...


class p_56(BaseTW): ...


class p_64(BaseTW): ...


class p_px(BaseTW): ...


class pb_0(BaseTW): ...


class pb_1(BaseTW): ...


class pb_2(BaseTW): ...


class pb_3(BaseTW): ...


class pb_4(BaseTW): ...


class pb_5(BaseTW): ...


class pb_6(BaseTW): ...


class pb_8(BaseTW): ...


class pb_10(BaseTW): ...


class pb_12(BaseTW): ...


class pb_16(BaseTW): ...


class pb_20(BaseTW): ...


class pb_24(BaseTW): ...


class pb_32(BaseTW): ...


class pb_40(BaseTW): ...


class pb_48(BaseTW): ...


class pb_56(BaseTW): ...


class pb_64(BaseTW): ...


class pb_px(BaseTW): ...


class pr_0(BaseTW): ...


class pr_1(BaseTW): ...


class pr_2(BaseTW): ...


class pr_3(BaseTW): ...


class pr_4(BaseTW): ...


class pr_5(BaseTW): ...


class pr_6(BaseTW): ...


class pr_8(BaseTW): ...


class pr_10(BaseTW): ...


class pr_12(BaseTW): ...


class pr_16(BaseTW): ...


class pr_20(BaseTW): ...


class pr_24(BaseTW): ...


class pr_32(BaseTW): ...


class pr_40(BaseTW): ...


class pr_48(BaseTW): ...


class pr_56(BaseTW): ...


class pr_64(BaseTW): ...


class pr_px(BaseTW): ...


class pt_0(BaseTW): ...


class pt_1(BaseTW): ...


class pt_2(BaseTW): ...


class pt_3(BaseTW): ...


class pt_4(BaseTW): ...


class pt_5(BaseTW): ...


class pt_6(BaseTW): ...


class pt_8(BaseTW): ...


class pt_10(BaseTW): ...


class pt_12(BaseTW): ...


class pt_16(BaseTW): ...


class pt_20(BaseTW): ...


class pt_24(BaseTW): ...


class pt_32(BaseTW): ...


class pt_40(BaseTW): ...


class pt_48(BaseTW): ...


class pt_56(BaseTW): ...


class pt_64(BaseTW): ...


class pt_px(BaseTW): ...


class pl_0(BaseTW): ...


class pl_1(BaseTW): ...


class pl_2(BaseTW): ...


class pl_3(BaseTW): ...


class pl_4(BaseTW): ...


class pl_5(BaseTW): ...


class pl_6(BaseTW): ...


class pl_8(BaseTW): ...


class pl_10(BaseTW): ...


class pl_12(BaseTW): ...


class pl_16(BaseTW): ...


class pl_20(BaseTW): ...


class pl_24(BaseTW): ...


class pl_32(BaseTW): ...


class pl_40(BaseTW): ...


class pl_48(BaseTW): ...


class pl_56(BaseTW): ...


class pl_64(BaseTW): ...


class pl_px(BaseTW): ...


class px_0(BaseTW): ...


class px_1(BaseTW): ...


class px_2(BaseTW): ...


class px_3(BaseTW): ...


class px_4(BaseTW): ...


class px_5(BaseTW): ...


class px_6(BaseTW): ...


class px_8(BaseTW): ...


class px_10(BaseTW): ...


class px_12(BaseTW): ...


class px_16(BaseTW): ...


class px_20(BaseTW): ...


class px_24(BaseTW): ...


class px_32(BaseTW): ...


class px_40(BaseTW): ...


class px_48(BaseTW): ...


class px_56(BaseTW): ...


class px_64(BaseTW): ...


class px_px(BaseTW): ...


class py_0(BaseTW): ...


class py_1(BaseTW): ...


class py_2(BaseTW): ...


class py_3(BaseTW): ...


class py_4(BaseTW): ...


class py_5(BaseTW): ...


class py_6(BaseTW): ...


class py_8(BaseTW): ...


class py_10(BaseTW): ...


class py_12(BaseTW): ...


class py_16(BaseTW): ...


class py_20(BaseTW): ...


class py_24(BaseTW): ...


class py_32(BaseTW): ...


class py_40(BaseTW): ...


class py_48(BaseTW): ...


class py_56(BaseTW): ...


class py_64(BaseTW): ...


class py_px(BaseTW): ...


class p_11(BaseTW): ...


class pb_11(BaseTW): ...


class pl_11(BaseTW): ...


class pr_11(BaseTW): ...


class pt_11(BaseTW): ...


class px_11(BaseTW): ...


class py_11(BaseTW): ...


class align(BaseTW): ...


class clear_left(BaseTW): ...


class clear_right(BaseTW): ...


class clear_both(BaseTW): ...


class clear_none(BaseTW): ...


class clearfix(BaseTW): ...


class float(BaseTW): ...


class inset_y_0(BaseTW): ...


class inset(BaseTW): ...


class top_0(BaseTW): ...


class top(BaseTW): ...


class left_0(BaseTW): ...


class left(BaseTW): ...


class right_0(BaseTW): ...


class right(BaseTW): ...


class bottom_0(BaseTW): ...


class bottom(BaseTW): ...


class object_center(BaseTW): ...


class object_bottom(BaseTW): ...


class object_left(BaseTW): ...


class object_left_bottom(BaseTW): ...


class object_left_top(BaseTW): ...


class object_right(BaseTW): ...


class object_right_bottom(BaseTW): ...


class object_right_top(BaseTW): ...


class object_top(BaseTW): ...


class object_contain(BaseTW): ...


class object(BaseTW): ...


class z_10(BaseTW): ...


class z(BaseTW): ...


class static(BaseTW): ...


class relative(BaseTW): ...


class absolute(BaseTW): ...


class fixed(BaseTW): ...


class sticky(BaseTW): ...


class _bottom_1(BaseTW): ...


class _bottom_px(BaseTW): ...


class _inset_0(BaseTW): ...


class _inset_px(BaseTW): ...


class _inset_x_0(BaseTW): ...


class _inset_y_0(BaseTW): ...


class _inset_y_full(BaseTW): ...


class _inset_y_px(BaseTW): ...


class _left_0(BaseTW): ...


class _left_full(BaseTW): ...


class _left_px(BaseTW): ...


class _m_0(BaseTW): ...


class _m_px(BaseTW): ...


class _mb_0(BaseTW): ...


class _mb_px(BaseTW): ...


class _ml_0(BaseTW): ...


class _ml_px(BaseTW): ...


class _mr_0(BaseTW): ...


class _mr_px(BaseTW): ...


class _mt_0(BaseTW): ...


class _mt_px(BaseTW): ...


class _mx_0(BaseTW): ...


class _mx_px(BaseTW): ...


class _my_0(BaseTW): ...


class _my_px(BaseTW): ...


class _right_0(BaseTW): ...


class _right_full(BaseTW): ...


class _right_px(BaseTW): ...


class _rotate_1(BaseTW): ...


class _skew_x_1(BaseTW): ...


class _skew_y_1(BaseTW): ...


class _space_x_0(BaseTW): ...


class _space_x_px(BaseTW): ...


class _space_y_0(BaseTW): ...


class _space_y_px(BaseTW): ...


class _top_0(BaseTW): ...


class _top_px(BaseTW): ...


class _translate_x_0(BaseTW): ...


class _translate_x_full(BaseTW): ...


class _translate_x_px(BaseTW): ...


class _translate_y_0(BaseTW): ...


class _translate_y_px(BaseTW): ...


class align_baseline(BaseTW): ...


class align_bottom(BaseTW): ...


class align_middle(BaseTW): ...


class align_text_bottom(BaseTW): ...


class align_text_top(BaseTW): ...


class align_top(BaseTW): ...


class bottom_auto(BaseTW): ...


class bottom_full(BaseTW): ...


class bottom_px(BaseTW): ...


class inset_1(BaseTW): ...


class inset_full(BaseTW): ...


class inset_px(BaseTW): ...


class inset_x_1(BaseTW): ...


class inset_x_full(BaseTW): ...


class inset_x_px(BaseTW): ...


class inset_y_1(BaseTW): ...


class inset_y_full(BaseTW): ...


class inset_y_px(BaseTW): ...


class left_1(BaseTW): ...


class left_full(BaseTW): ...


class left_px(BaseTW): ...


class right_1(BaseTW): ...


class right_auto(BaseTW): ...


class right_full(BaseTW): ...


class right_px(BaseTW): ...


class top_full(BaseTW): ...


class top_px(BaseTW): ...


class hover(BaseTW): ...


class focus(BaseTW): ...


class container(BaseTW): ...


class sm_(BaseTW):
    tag = "sm:"


class md_(BaseTW):
    tag = "md:"


class lg_(BaseTW):
    tag = "lg:"


class xl_(BaseTW):
    tag = "xl:"


class ring(BaseTW): ...


class ring_0(BaseTW): ...


class ring_black(BaseTW): ...


class ring_blue_100(BaseTW): ...


class ring_current(BaseTW): ...


class ring_gray_100(BaseTW): ...


class ring_green_100(BaseTW): ...


class ring_inding_100(BaseTW): ...


class ring_inset(BaseTW): ...


class ring_offset_0(BaseTW): ...


class ring_offset_black(BaseTW): ...


class ring_offset_blue_100(BaseTW): ...


class ring_offset_current(BaseTW): ...


class ring_offset_gray_100(BaseTW): ...


class ring_offset_green_100(BaseTW): ...


class ring_offset_indigo_100(BaseTW): ...


class ring_offset_pink_100(BaseTW): ...


class ring_offset_purple_100(BaseTW): ...


class ring_offset_red_100(BaseTW): ...


class ring_offset_transparent(BaseTW): ...


class ring_offset_white(BaseTW): ...


class ring_offset_yellow_100(BaseTW): ...


class ring_opacity_0(BaseTW): ...


class ring_pink_100(BaseTW): ...


class ring_purple_100(BaseTW): ...


class ring_red_100(BaseTW): ...


class ring_transparent(BaseTW): ...


class ring_white(BaseTW): ...


class ring_yellow_100(BaseTW): ...


class overscroll_contain(BaseTW): ...


class overscroll_x_auto(BaseTW): ...


class overscroll_x_contain(BaseTW): ...


class overscroll_x_none(BaseTW): ...


class overscroll_y_auto(BaseTW): ...


class overscroll_y_contain(BaseTW): ...


class overscroll_y_none(BaseTW): ...


class shadow_xs(BaseTW): ...


class shadow_sm(BaseTW): ...


class shadow(BaseTW): ...


class shadow_md(BaseTW): ...


class shadow_lg(BaseTW): ...


class shadow_xl(BaseTW): ...


class shadow_2xl(BaseTW): ...


class shadow_inner(BaseTW): ...


class shadow_outline(BaseTW): ...


class shadow_none(BaseTW): ...


class h_11(BaseTW): ...


class space_x_1(BaseTW): ...


class space_x(BaseTW): ...


class space_y_1(BaseTW): ...


class space_y(BaseTW): ...


class _space_x_1(BaseTW): ...


class _space_x(BaseTW): ...


class _space_y_1(BaseTW): ...


class _space_y(BaseTW): ...


class fill_current(BaseTW): ...


class stroke_current(BaseTW): ...


class stroke_0(BaseTW): ...


class stroke(BaseTW): ...


class table(BaseTW): ...


class table_caption(BaseTW): ...


class table_cell(BaseTW): ...


class table_column(BaseTW): ...


class table_column_group(BaseTW): ...


class table_footer_group(BaseTW): ...


class table_header_group(BaseTW): ...


class table_row_group(BaseTW): ...


class table_row(BaseTW): ...


class table_auto(BaseTW): ...


class table_fixed(BaseTW): ...


class Text(BaseTW): ...


class antialiased(BaseTW): ...


class subpixel_antialiased(BaseTW): ...


class text_opacity(BaseTW): ...


class break_normal(BaseTW): ...


class break_words(BaseTW): ...


class break_all(BaseTW): ...


class truncate(BaseTW): ...


class uppercase(BaseTW): ...


class lowercase(BaseTW): ...


class capitalize(BaseTW): ...


class normal_case(BaseTW): ...


class leading_none(BaseTW): ...


class leading_tight(BaseTW): ...


class leading_snug(BaseTW): ...


class leading_normal(BaseTW): ...


class leading_relaxed(BaseTW): ...


class leading_loose(BaseTW): ...


class leading_3(BaseTW): ...


class leading_4(BaseTW): ...


class leading_5(BaseTW): ...


class leading_6(BaseTW): ...


class leading_7(BaseTW): ...


class leading_8(BaseTW): ...


class leading_9(BaseTW): ...


class leading_10(BaseTW): ...


class underline(BaseTW): ...


class line_through(BaseTW): ...


class no_underline(BaseTW): ...


class font_hairline(BaseTW): ...


class font_thin(BaseTW): ...


class font_light(BaseTW): ...


class font_normal(BaseTW): ...


class font_medium(BaseTW): ...


class font_semibold(BaseTW): ...


class font_bold(BaseTW): ...


class font_extrabold(BaseTW): ...


class font_black(BaseTW): ...


class text_xs(BaseTW): ...


class text_sm(BaseTW): ...


class text_base(BaseTW): ...


class text_lg(BaseTW): ...


class text_xl(BaseTW): ...


class text_2xl(BaseTW): ...


class text_3xl(BaseTW): ...


class text_4xl(BaseTW): ...


class text_5xl(BaseTW): ...


class text_6xl(BaseTW): ...


class font_sans(BaseTW): ...


class font_serif(BaseTW): ...


class font_mono(BaseTW): ...


class text_left(BaseTW): ...


class text_center(BaseTW): ...


class text_right(BaseTW): ...


class text_justify(BaseTW): ...


class italic(BaseTW): ...


class not_italic(BaseTW): ...


class whitespace_normal(BaseTW): ...


class whitespace(BaseTW): ...


class tracking_tighter(BaseTW): ...


class tracking_tight(BaseTW): ...


class tracking_normal(BaseTW): ...


class tracking_wide(BaseTW): ...


class tracking_wider(BaseTW): ...


class tracking_widest(BaseTW): ...


class text_transparent(BaseTW): ...


class text_current(BaseTW): ...


class text_black(BaseTW): ...


class text_white(BaseTW): ...


class text_gray_100(BaseTW): ...


class text_gray_200(BaseTW): ...


class text_gray_300(BaseTW): ...


class text_gray_400(BaseTW): ...


class text_gray_500(BaseTW): ...


class text_gray_600(BaseTW): ...


class text_gray_700(BaseTW): ...


class text_gray_800(BaseTW): ...


class text_gray_900(BaseTW): ...


class text_red_100(BaseTW): ...


class text_red_200(BaseTW): ...


class text_red_300(BaseTW): ...


class text_red_400(BaseTW): ...


class text_red_500(BaseTW): ...


class text_red_600(BaseTW): ...


class text_red_700(BaseTW): ...


class text_red_800(BaseTW): ...


class text_red_900(BaseTW): ...


class text_orange_100(BaseTW): ...


class text_orange_200(BaseTW): ...


class text_orange_300(BaseTW): ...


class text_orange_400(BaseTW): ...


class text_orange_500(BaseTW): ...


class text_orange_600(BaseTW): ...


class text_orange_700(BaseTW): ...


class text_orange_800(BaseTW): ...


class text_orange_900(BaseTW): ...


class text_yellow_100(BaseTW): ...


class text_yellow_200(BaseTW): ...


class text_yellow_300(BaseTW): ...


class text_yellow_400(BaseTW): ...


class text_yellow_500(BaseTW): ...


class text_yellow_600(BaseTW): ...


class text_yellow_700(BaseTW): ...


class text_yellow_800(BaseTW): ...


class text_yellow_900(BaseTW): ...


class text_green_100(BaseTW): ...


class text_green_200(BaseTW): ...


class text_green_300(BaseTW): ...


class text_green_400(BaseTW): ...


class text_green_500(BaseTW): ...


class text_green_600(BaseTW): ...


class text_green_700(BaseTW): ...


class text_green_800(BaseTW): ...


class text_green_900(BaseTW): ...


class text_teal_100(BaseTW): ...


class text_teal_200(BaseTW): ...


class text_teal_300(BaseTW): ...


class text_teal_400(BaseTW): ...


class text_teal_500(BaseTW): ...


class text_teal_600(BaseTW): ...


class text_teal_700(BaseTW): ...


class text_teal_800(BaseTW): ...


class text_teal_900(BaseTW): ...


class text_blue_100(BaseTW): ...


class text_blue_200(BaseTW): ...


class text_blue_300(BaseTW): ...


class text_blue_400(BaseTW): ...


class text_blue_500(BaseTW): ...


class text_blue_600(BaseTW): ...


class text_blue_700(BaseTW): ...


class text_blue_800(BaseTW): ...


class text_blue_900(BaseTW): ...


class text_indigo_100(BaseTW): ...


class text_indigo_200(BaseTW): ...


class text_indigo_300(BaseTW): ...


class text_indigo_400(BaseTW): ...


class text_indigo_500(BaseTW): ...


class text_indigo_600(BaseTW): ...


class text_indigo_700(BaseTW): ...


class text_indigo_800(BaseTW): ...


class text_indigo_900(BaseTW): ...


class text_purple_100(BaseTW): ...


class text_purple_200(BaseTW): ...


class text_purple_300(BaseTW): ...


class text_purple_400(BaseTW): ...


class text_purple_500(BaseTW): ...


class text_purple_600(BaseTW): ...


class text_purple_700(BaseTW): ...


class text_purple_800(BaseTW): ...


class text_purple_900(BaseTW): ...


class text_pink_100(BaseTW): ...


class text_pink_200(BaseTW): ...


class text_pink_300(BaseTW): ...


class text_pink_400(BaseTW): ...


class text_pink_500(BaseTW): ...


class text_pink_600(BaseTW): ...


class text_pink_700(BaseTW): ...


class text_pink_900(BaseTW): ...


class text_pink_800(BaseTW): ...


class text_blue_50(BaseTW): ...


class text_gray_50(BaseTW): ...


class text_green_50(BaseTW): ...


class text_indigo_50(BaseTW): ...


class text_opacity_10(BaseTW): ...


class text_pink_50(BaseTW): ...


class text_purple_50(BaseTW): ...


class text_red_50(BaseTW): ...


class text_yellow_50(BaseTW): ...


class Transform(BaseTW): ...


class transform(BaseTW): ...


class transform_none(BaseTW): ...


class origin_center(BaseTW): ...


class origin(BaseTW): ...


class translate_x_0(BaseTW): ...


class translate_x_1(BaseTW): ...


class translate_x_2(BaseTW): ...


class translate_x_3(BaseTW): ...


class translate_x_4(BaseTW): ...


class translate_x_5(BaseTW): ...


class translate_x_6(BaseTW): ...


class translate_x_8(BaseTW): ...


class translate_x_10(BaseTW): ...


class translate_x_12(BaseTW): ...


class translate_x_16(BaseTW): ...


class translate_x_20(BaseTW): ...


class translate_x_24(BaseTW): ...


class translate_x_32(BaseTW): ...


class translate_x_40(BaseTW): ...


class translate_x_48(BaseTW): ...


class translate_x_56(BaseTW): ...


class translate_x_64(BaseTW): ...


class translate_x_px(BaseTW): ...


class translate_x_1_2(BaseTW):
    tag = "translate-x-1/2"


class translate_x_full(BaseTW): ...


class translate_y_0(BaseTW): ...


class translate_y_1(BaseTW): ...


class translate_y_2(BaseTW): ...


class translate_y_3(BaseTW): ...


class translate_y_4(BaseTW): ...


class translate_y_5(BaseTW): ...


class translate_y_6(BaseTW): ...


class translate_y_8(BaseTW): ...


class translate_y_10(BaseTW): ...


class translate_y_12(BaseTW): ...


class translate_y_16(BaseTW): ...


class translate_y_20(BaseTW): ...


class translate_y_24(BaseTW): ...


class translate_y_32(BaseTW): ...


class translate_y_40(BaseTW): ...


class translate_y_48(BaseTW): ...


class translate_y_56(BaseTW): ...


class translate_y_64(BaseTW): ...


class translate_y_px(BaseTW): ...


class translate_y_1_2(BaseTW):
    tag = "translate-y-1/2"


class translate_y_full(BaseTW): ...


class _translate_x_1(BaseTW): ...


class _translate_x_2(BaseTW): ...


class _translate_x_3(BaseTW): ...


class _translate_x_4(BaseTW): ...


class _translate_x_5(BaseTW): ...


class _translate_x_6(BaseTW): ...


class _translate_x_8(BaseTW): ...


class _translate_x_10(BaseTW): ...


class _translate_x_12(BaseTW): ...


class _translate_x_16(BaseTW): ...


class _translate_x_20(BaseTW): ...


class _translate_x_24(BaseTW): ...


class _translate_x_32(BaseTW): ...


class _translate_x_40(BaseTW): ...


class _translate_x_48(BaseTW): ...


class _translate_x_56(BaseTW): ...


class _translate_x_64(BaseTW): ...


class _translate_x_px(BaseTW): ...


class _translate_x_1_2(BaseTW):
    tag = "-translate-x-1/2"


class _translate_x_full(BaseTW): ...


class _translate_y_1(BaseTW): ...


class _translate_y_2(BaseTW): ...


class _translate_y_3(BaseTW): ...


class _translate_y_4(BaseTW): ...


class _translate_y_5(BaseTW): ...


class _translate_y_6(BaseTW): ...


class _translate_y_8(BaseTW): ...


class _translate_y_10(BaseTW): ...


class _translate_y_12(BaseTW): ...


class _translate_y_16(BaseTW): ...


class _translate_y_20(BaseTW): ...


class _translate_y_24(BaseTW): ...


class _translate_y_32(BaseTW): ...


class _translate_y_40(BaseTW): ...


class _translate_y_48(BaseTW): ...


class _translate_y_56(BaseTW): ...


class _translate_y_64(BaseTW): ...


class _translate_y_px(BaseTW): ...


class _translate_y_1_2(BaseTW):
    tag = "-translate-y-1/2"


class _translate_y_full(BaseTW): ...


class scale_0(BaseTW): ...


class scale(BaseTW): ...


class scale_x_0(BaseTW): ...


class scale_x_50(BaseTW): ...


class scale_x_75(BaseTW): ...


class scale_x_90(BaseTW): ...


class scale_x_95(BaseTW): ...


class scale_x_100(BaseTW): ...


class scale_x_105(BaseTW): ...


class scale_x_110(BaseTW): ...


class scale_x_125(BaseTW): ...


class scale_x_150(BaseTW): ...


class scale_y_0(BaseTW): ...


class scale_y_50(BaseTW): ...


class scale_y_75(BaseTW): ...


class scale_y_90(BaseTW): ...


class scale_y_95(BaseTW): ...


class scale_y_100(BaseTW): ...


class scale_y_105(BaseTW): ...


class scale_y_110(BaseTW): ...


class scale_y_125(BaseTW): ...


class scale_y_150(BaseTW): ...


class rotate_0(BaseTW): ...


class rotate_45(BaseTW): ...


class rotate_90(BaseTW): ...


class rotate_180(BaseTW): ...


class _rotate_45(BaseTW): ...


class _rotate_90(BaseTW): ...


class _rotate_180(BaseTW): ...


class skew_x_0(BaseTW): ...


class skew_x_3(BaseTW): ...


class skew_x_6(BaseTW): ...


class skew_x_12(BaseTW): ...


class skew_y_0(BaseTW): ...


class skew_y_3(BaseTW): ...


class skew_y_6(BaseTW): ...


class skew_y_12(BaseTW): ...


class _skew_x_3(BaseTW): ...


class _skew_x_6(BaseTW): ...


class _skew_x_12(BaseTW): ...


class _skew_y_3(BaseTW): ...


class _skew_y_6(BaseTW): ...


class _skew_y_12(BaseTW): ...


class diagonal_fractions(BaseTW): ...


class rotate_1(BaseTW): ...


class skew_x_1(BaseTW): ...


class skew_x_2(BaseTW): ...


class skew_y_1(BaseTW): ...


class skew_y_2(BaseTW): ...


class transform_gpu(BaseTW): ...


class translate_x_11(BaseTW): ...


class translate_y_11(BaseTW): ...


class font_extralight(BaseTW): ...


class text_7xl(BaseTW): ...


class text_8xl(BaseTW): ...


class text_9xl(BaseTW): ...


class Utilities(BaseTW): ...


class cursor_auto(BaseTW): ...


class cursor_default(BaseTW): ...


class cursor_move(BaseTW): ...


class cursor_pointer(BaseTW): ...


class cursor_text(BaseTW): ...


class cursor_wait(BaseTW): ...


class cursor_not_allowed(BaseTW): ...


class appearance_none(BaseTW): ...


class placeholder_transparent__placeholder(BaseTW):
    tag = "placeholder-transparent::placeholder"


class placeholder_current__placeholder(BaseTW):
    tag = "placeholder-current::placeholder"


class placeholder_black__placeholder(BaseTW):
    tag = "placeholder-black::placeholder"


class placeholder_white__placeholder(BaseTW):
    tag = "placeholder-white::placeholder"


class placeholder_gray_600__placeholder(BaseTW):
    tag = "placeholder-gray-600::placeholder"


class placeholder_red_600__placeholder(BaseTW):
    tag = "placeholder-red-600::placeholder"


class placeholder_orange_600__placeholder(BaseTW):
    tag = "placeholder-orange-600::placeholder"


class placeholder_yellow_600__placeholder(BaseTW):
    tag = "placeholder-yellow-600::placeholder"


class placeholder_green_600__placeholder(BaseTW):
    tag = "placeholder-green-600::placeholder"


class placeholder_teal_600__placeholder(BaseTW):
    tag = "placeholder-teal-600::placeholder"


class placeholder_blue_600__placeholder(BaseTW):
    tag = "placeholder-blue-600::placeholder"


class placeholder_indigo_600__placeholder(BaseTW):
    tag = "placeholder-indigo-600::placeholder"


class placeholder_purple_600__placeholder(BaseTW):
    tag = "placeholder-purple-600::placeholder"


class placeholder_pink_600__placeholder(BaseTW):
    tag = "placeholder-pink-600::placeholder"


class placeholder_gray_100__placeholder(BaseTW):
    tag = "placeholder-gray-100::placeholder"


class placeholder_gray_200__placeholder(BaseTW):
    tag = "placeholder-gray-200::placeholder"


class placeholder_gray_300__placeholder(BaseTW):
    tag = "placeholder-gray-300::placeholder"


class placeholder_gray_400__placeholder(BaseTW):
    tag = "placeholder-gray-400::placeholder"


class placeholder_gray_500__placeholder(BaseTW):
    tag = "placeholder-gray-500::placeholder"


class placeholder_gray_700__placeholder(BaseTW):
    tag = "placeholder-gray-700::placeholder"


class placeholder_gray_800__placeholder(BaseTW):
    tag = "placeholder-gray-800::placeholder"


class placeholder_gray_900__placeholder(BaseTW):
    tag = "placeholder-gray-900::placeholder"


class placeholder_opacity_0(BaseTW): ...


class placeholder_opacity_25(BaseTW): ...


class placeholder_opacity_50(BaseTW): ...


class placeholder_opacity_75(BaseTW): ...


class placeholder_opacity_100(BaseTW): ...


class outline_none(BaseTW): ...


class overflow_hidden(BaseTW): ...


class overflow(BaseTW): ...


class scrolling_touch(BaseTW): ...


class scrolling_auto(BaseTW): ...


class pointer_events_none(BaseTW): ...


class pointer_events_auto(BaseTW): ...


class resize(BaseTW): ...


class resize_none(BaseTW): ...


class resize_y(BaseTW): ...


class resize_x(BaseTW): ...


class select_none(BaseTW): ...


class select_text(BaseTW): ...


class select_all(BaseTW): ...


class select_auto(BaseTW): ...


class placeholder_blue_100(BaseTW): ...


class placeholder_current(BaseTW): ...


class placeholder_gray_100(BaseTW): ...


class placeholder_green_100(BaseTW): ...


class placeholder_indigo_100(BaseTW): ...


class placeholder_opacity_10(BaseTW): ...


class placeholder_pink_100(BaseTW): ...


class placeholder_purple_100(BaseTW): ...


class placeholder_red_100(BaseTW): ...


class placeholder_transparent(BaseTW): ...


class placeholder_white(BaseTW): ...


class placeholder_yellow_100(BaseTW): ...


class opacity_100(BaseTW): ...


class opacity_75(BaseTW): ...


class opacity_50(BaseTW): ...


class opacity_25(BaseTW): ...


class opacity_0(BaseTW): ...


class visible(BaseTW): ...


class invisible(BaseTW): ...


class sr_only(BaseTW): ...


class not_sr_only(BaseTW): ...


class w_0(BaseTW): ...


class w_1(BaseTW): ...


class w_2(BaseTW): ...


class w_3(BaseTW): ...


class w_4(BaseTW): ...


class w_5(BaseTW): ...


class w_6(BaseTW): ...


class w_8(BaseTW): ...


class w_10(BaseTW): ...


class w_12(BaseTW): ...


class w_16(BaseTW): ...


class w_20(BaseTW): ...


class w_24(BaseTW): ...


class w_32(BaseTW): ...


class w_40(BaseTW): ...


class w_48(BaseTW): ...


class w_56(BaseTW): ...


class w_64(BaseTW): ...


class w_auto(BaseTW): ...


class w_px(BaseTW): ...


class w_full(BaseTW): ...


class w_screen(BaseTW): ...


class w_1_2(BaseTW):
    tag = "w-1/2"


class w_1_3(BaseTW):
    tag = "w-1/3"


class w_2_3(BaseTW):
    tag = "w-2/3"


class w_1_4(BaseTW):
    tag = "w-1/4"


class w_2_4(BaseTW):
    tag = "w-2/4"


class w_3_4(BaseTW):
    tag = "w-3/4"


class w_1_5(BaseTW):
    tag = "w-1/5"


class w_2_5(BaseTW):
    tag = "w-2/5"


class w_3_5(BaseTW):
    tag = "w-3/5"


class w_4_5(BaseTW):
    tag = "w-4/5"


class w_1_6(BaseTW):
    tag = "w-1/6"


class w_2_6(BaseTW):
    tag = "w-2/6"


class w_3_6(BaseTW):
    tag = "w-3/6"


class w_4_6(BaseTW):
    tag = "w-4/6"


class w_5_6(BaseTW):
    tag = "w-5/6"


class w_1_12(BaseTW):
    tag = "w-1/12"


class w_2_12(BaseTW):
    tag = "w-2/12"


class w_3_12(BaseTW):
    tag = "w-3/12"


class w_4_12(BaseTW):
    tag = "w-4/12"


class w_5_12(BaseTW):
    tag = "w-5/12"


class w_6_12(BaseTW):
    tag = "w-6/12"


class w_7_12(BaseTW):
    tag = "w-7/12"


class w_8_12(BaseTW):
    tag = "w-8/12"


class w_9_12(BaseTW):
    tag = "w-9/12"


class w_10_12(BaseTW):
    tag = "w-10/12"


class w_11_12(BaseTW):
    tag = "w-11/12"


class max_w_xs(BaseTW): ...


class max_w_sm(BaseTW): ...


class max_w_md(BaseTW): ...


class max_w_lg(BaseTW): ...


class max_w_xl(BaseTW): ...


class max_w_2xl(BaseTW): ...


class max_w_3xl(BaseTW): ...


class max_w_4xl(BaseTW): ...


class max_w_5xl(BaseTW): ...


class max_w_6xl(BaseTW): ...


class max_w_full(BaseTW): ...


class max_w_screen_sm(BaseTW): ...


class max_w_screen_md(BaseTW): ...


class max_w_screen_lg(BaseTW): ...


class max_w_screen_xl(BaseTW): ...


class max_w_none(BaseTW): ...


class min_w_0(BaseTW): ...


class min_w_full(BaseTW): ...


class max_h_0(BaseTW): ...


class max_w_0(BaseTW): ...


class max_w_7xl(BaseTW): ...


class max_w_max(BaseTW): ...


class max_w_min(BaseTW): ...


class max_w_prose(BaseTW): ...


class max_w_screen_2xl(BaseTW): ...


class min_w_max(BaseTW): ...


class min_w_min(BaseTW): ...


class w_11(BaseTW): ...
