from inui.base import BaseSvgElement


class A(BaseSvgElement): ...


class Animate(BaseSvgElement): ...


class Animatemotion(BaseSvgElement): ...


class Animatetransform(BaseSvgElement): ...


class Circle(BaseSvgElement): ...


class Clippath(BaseSvgElement): ...


class Cursor(BaseSvgElement): ...


class Defs(BaseSvgElement): ...


class Desc(BaseSvgElement): ...


class Ellipse(BaseSvgElement): ...


class Feblend(BaseSvgElement): ...


class Fecolormatrix(BaseSvgElement): ...


class Fecomponenttransfer(BaseSvgElement): ...


class Fecomposite(BaseSvgElement): ...


class Feconvolvematrix(BaseSvgElement): ...


class Fediffuselighting(BaseSvgElement): ...


class Fedisplacementmap(BaseSvgElement): ...


class Fedistantlight(BaseSvgElement): ...


class Fedropshadow(BaseSvgElement): ...


class Feflood(BaseSvgElement): ...


class Fefunca(BaseSvgElement): ...


class Fefuncb(BaseSvgElement): ...


class Fefuncg(BaseSvgElement): ...


class Fefuncr(BaseSvgElement): ...


class Fegaussianblur(BaseSvgElement): ...


class Feimage(BaseSvgElement): ...


class Femerge(BaseSvgElement): ...


class Femergenode(BaseSvgElement): ...


class Femorphology(BaseSvgElement): ...


class Feoffset(BaseSvgElement): ...


class Fepointlight(BaseSvgElement): ...


class Fespecularlighting(BaseSvgElement): ...


class Fespotlight(BaseSvgElement): ...


class Fetile(BaseSvgElement): ...


class Feturbulence(BaseSvgElement): ...


class Filter(BaseSvgElement): ...


class Font(BaseSvgElement): ...


class Font_face(BaseSvgElement): ...


class Font_face_format(BaseSvgElement): ...


class Font_face_name(BaseSvgElement): ...


class Font_face_src(BaseSvgElement): ...


class Font_face_uri(BaseSvgElement): ...


class Foreignobject(BaseSvgElement): ...


class G(BaseSvgElement): ...


class Glyph(BaseSvgElement): ...


class Glyphref(BaseSvgElement): ...


class Hkern(BaseSvgElement): ...


class Image(BaseSvgElement): ...


class Line(BaseSvgElement): ...


class Lineargradient(BaseSvgElement): ...


class Marker(BaseSvgElement): ...


class Mask(BaseSvgElement): ...


class Metadata(BaseSvgElement): ...


class Missing_glyph(BaseSvgElement): ...


class Mpath(BaseSvgElement): ...


class Path(BaseSvgElement): ...


class Pattern(BaseSvgElement): ...


class Polygon(BaseSvgElement): ...


class Polyline(BaseSvgElement): ...


class Radialgradient(BaseSvgElement): ...


class Rect(BaseSvgElement): ...


class ScriptSvg(BaseSvgElement): ...


class Set(BaseSvgElement): ...


class Stop(BaseSvgElement): ...


class Style(BaseSvgElement): ...


class Svg(BaseSvgElement): ...


class Switch(BaseSvgElement): ...


class Symbol(BaseSvgElement): ...


class Text(BaseSvgElement): ...


class Textpath(BaseSvgElement): ...


class Title(BaseSvgElement): ...


class Tref(BaseSvgElement): ...


class Tspan(BaseSvgElement): ...


class Use(BaseSvgElement): ...


class View(BaseSvgElement): ...


class Vkern(BaseSvgElement): ...
