BOOTSTRAP_VERSION = "5.3.3"

BOOTSTRAP_CSS_URL = (
    "https://cdn.jsdelivr.net/npm/bootstrap@%s/dist/css/bootstrap.min.css"
    % BOOTSTRAP_VERSION
)
BOOTSTRAP_JS_URL = (
    "https://cdn.jsdelivr.net/npm/bootstrap@%s/dist/js/bootstrap.bundle.min.js"
    % BOOTSTRAP_VERSION
)

TAILWINDCSS_URL = "https://cdn.tailwindcss.com"

TAILWINDCSS_CONFIG = {}

TAILWINDCSS_CUSTOM_CSS = ""
